// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package worklink provides the client and types for making API
// requests to Amazon WorkLink.
//
// Amazon WorkLink is a cloud-based service that provides secure access to internal
// websites and web apps from iOS and Android phones. In a single step, your
// users, such as employees, can access internal websites as efficiently as
// they access any other public website. They enter a URL in their web browser,
// or choose a link to an internal website in an email. Amazon WorkLink authenticates
// the user's access and securely renders authorized internal web content in
// a secure rendering service in the AWS cloud. Amazon WorkLink doesn't download
// or store any internal web content on mobile devices.
//
// See https://docs.aws.amazon.com/goto/WebAPI/worklink-2018-09-25 for more information on this service.
//
// See worklink package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/worklink/
//
// Using the Client
//
// To contact Amazon WorkLink with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon WorkLink client WorkLink for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/worklink/#New
package worklink
