// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package cloudhsmv2 provides the client and types for making API
// requests to AWS CloudHSM V2.
//
// For more information about AWS CloudHSM, see AWS CloudHSM (http://aws.amazon.com/cloudhsm/)
// and the AWS CloudHSM User Guide (https://docs.aws.amazon.com/cloudhsm/latest/userguide/).
//
// See https://docs.aws.amazon.com/goto/WebAPI/cloudhsmv2-2017-04-28 for more information on this service.
//
// See cloudhsmv2 package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/cloudhsmv2/
//
// Using the Client
//
// To contact AWS CloudHSM V2 with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS CloudHSM V2 client CloudHSMV2 for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/cloudhsmv2/#New
package cloudhsmv2
