// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package augmentedairuntime provides the client and types for making API
// requests to Amazon Augmented AI Runtime.
//
//
// Amazon Augmented AI is in preview release and is subject to change. We do
// not recommend using this product in production environments.
//
// Amazon Augmented AI (Amazon A2I) adds the benefit of human judgment to any
// machine learning application. When an AI application can't evaluate data
// with a high degree of confidence, human reviewers can take over. This human
// review is called a human review workflow. To create and start a human review
// workflow, you need three resources: a worker task template, a flow definition,
// and a human loop.
//
// For information about these resources and prerequisites for using Amazon
// A2I, see Get Started with Amazon Augmented AI (https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-getting-started.html)
// in the Amazon SageMaker Developer Guide.
//
// This API reference includes information about API actions and data types
// that you can use to interact with Amazon A2I programmatically. Use this guide
// to:
//
//    * Start a human loop with the StartHumanLoop operation when using Amazon
//    A2I with a custom task type. To learn more about the difference between
//    custom and built-in task types, see Use Task Types (https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-task-types-general.html).
//    To learn how to start a human loop using this API, see Create and Start
//    a Human Loop for a Custom Task Type (https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-start-human-loop.html#a2i-instructions-starthumanloop)
//    in the Amazon SageMaker Developer Guide.
//
//    * Manage your human loops. You can list all human loops that you have
//    created, describe individual human loops, and stop and delete human loops.
//    To learn more, see Monitor and Manage Your Human Loop (https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-monitor-humanloop-results.html)
//    in the Amazon SageMaker Developer Guide.
//
// Amazon A2I integrates APIs from various AWS services to create and start
// human review workflows for those services. To learn how Amazon A2I uses these
// APIs, see Use APIs in Amazon A2I (https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-api-references.html)
// in the Amazon SageMaker Developer Guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/sagemaker-a2i-runtime-2019-11-07 for more information on this service.
//
// See augmentedairuntime package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/augmentedairuntime/
//
// Using the Client
//
// To contact Amazon Augmented AI Runtime with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Augmented AI Runtime client AugmentedAIRuntime for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/augmentedairuntime/#New
package augmentedairuntime
