// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package swf provides the client and types for making API
// requests to Amazon Simple Workflow Service.
//
// The Amazon Simple Workflow Service (Amazon SWF) makes it easy to build applications
// that use Amazon's cloud to coordinate work across distributed components.
// In Amazon SWF, a task represents a logical unit of work that is performed
// by a component of your workflow. Coordinating tasks in a workflow involves
// managing intertask dependencies, scheduling, and concurrency in accordance
// with the logical flow of the application.
//
// Amazon SWF gives you full control over implementing tasks and coordinating
// them without worrying about underlying complexities such as tracking their
// progress and maintaining their state.
//
// This documentation serves as reference only. For a broader overview of the
// Amazon SWF programming model, see the Amazon SWF Developer Guide (https://docs.aws.amazon.com/amazonswf/latest/developerguide/) .
//
// See swf package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/swf/
//
// Using the Client
//
// To contact Amazon Simple Workflow Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Simple Workflow Service client SWF for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/swf/#New
package swf
