// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package costexplorer provides the client and types for making API
// requests to AWS Cost Explorer Service.
//
// The Cost Explorer API enables you to programmatically query your cost and
// usage data. You can query for aggregated data such as total monthly costs
// or total daily usage. You can also query for granular data, such as the number
// of daily write operations for Amazon DynamoDB database tables in your production
// environment.
//
// Service Endpoint
//
// The Cost Explorer API provides the following endpoint:
//
//    * https://ce.us-east-1.amazonaws.com
//
// For information about costs associated with the Cost Explorer API, see AWS
// Cost Management Pricing (http://aws.amazon.com/aws-cost-management/pricing/).
//
// See https://docs.aws.amazon.com/goto/WebAPI/ce-2017-10-25 for more information on this service.
//
// See costexplorer package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/costexplorer/
//
// Using the Client
//
// To contact AWS Cost Explorer Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Cost Explorer Service client CostExplorer for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/costexplorer/#New
package costexplorer
