// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package lakeformation

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAlreadyExistsException for service response error code
	// "AlreadyExistsException".
	//
	// A resource to be created or added already exists.
	ErrCodeAlreadyExistsException = "AlreadyExistsException"

	// ErrCodeConcurrentModificationException for service response error code
	// "ConcurrentModificationException".
	//
	// Two processes are trying to modify a resource simultaneously.
	ErrCodeConcurrentModificationException = "ConcurrentModificationException"

	// ErrCodeEntityNotFoundException for service response error code
	// "EntityNotFoundException".
	//
	// A specified entity does not exist
	ErrCodeEntityNotFoundException = "EntityNotFoundException"

	// ErrCodeInternalServiceException for service response error code
	// "InternalServiceException".
	//
	// An internal service error occurred.
	ErrCodeInternalServiceException = "InternalServiceException"

	// ErrCodeInvalidInputException for service response error code
	// "InvalidInputException".
	//
	// The input provided was not valid.
	ErrCodeInvalidInputException = "InvalidInputException"

	// ErrCodeOperationTimeoutException for service response error code
	// "OperationTimeoutException".
	//
	// The operation timed out.
	ErrCodeOperationTimeoutException = "OperationTimeoutException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AlreadyExistsException":          newErrorAlreadyExistsException,
	"ConcurrentModificationException": newErrorConcurrentModificationException,
	"EntityNotFoundException":         newErrorEntityNotFoundException,
	"InternalServiceException":        newErrorInternalServiceException,
	"InvalidInputException":           newErrorInvalidInputException,
	"OperationTimeoutException":       newErrorOperationTimeoutException,
}
