// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package iotthingsgraph provides the client and types for making API
// requests to AWS IoT Things Graph.
//
// AWS IoT Things Graph provides an integrated set of tools that enable developers
// to connect devices and services that use different standards, such as units
// of measure and communication protocols. AWS IoT Things Graph makes it possible
// to build IoT applications with little to no code by connecting devices and
// services and defining how they interact at an abstract level.
//
// For more information about how AWS IoT Things Graph works, see the User Guide
// (https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-whatis.html).
//
// See https://docs.aws.amazon.com/goto/WebAPI/iotthingsgraph-2018-09-06 for more information on this service.
//
// See iotthingsgraph package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotthingsgraph/
//
// Using the Client
//
// To contact AWS IoT Things Graph with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS IoT Things Graph client IoTThingsGraph for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotthingsgraph/#New
package iotthingsgraph
