// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package sagemakerfeaturestoreruntime provides the client and types for making API
// requests to Amazon SageMaker Feature Store Runtime.
//
// Contains all data plane API operations and data types for the Amazon SageMaker
// Feature Store. Use this API to put, delete, and retrieve (get) features from
// a feature store.
//
// Use the following operations to configure your OnlineStore and OfflineStore
// features, and to create and manage feature groups:
//
//    * CreateFeatureGroup (https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFeatureGroup.html)
//
//    * DeleteFeatureGroup (https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteFeatureGroup.html)
//
//    * DescribeFeatureGroup (https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFeatureGroup.html)
//
//    * ListFeatureGroups (https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListFeatureGroups.html)
//
// See https://docs.aws.amazon.com/goto/WebAPI/sagemaker-featurestore-runtime-2020-07-01 for more information on this service.
//
// See sagemakerfeaturestoreruntime package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemakerfeaturestoreruntime/
//
// Using the Client
//
// To contact Amazon SageMaker Feature Store Runtime with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon SageMaker Feature Store Runtime client SageMakerFeatureStoreRuntime for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemakerfeaturestoreruntime/#New
package sagemakerfeaturestoreruntime
