// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package elasticache provides the client and types for making API
// requests to Amazon ElastiCache.
//
// Amazon ElastiCache is a web service that makes it easier to set up, operate,
// and scale a distributed cache in the cloud.
//
// With ElastiCache, customers get all of the benefits of a high-performance,
// in-memory cache with less of the administrative burden involved in launching
// and managing a distributed cache. The service makes setup, scaling, and cluster
// failure handling much simpler than in a self-managed cache deployment.
//
// In addition, through integration with Amazon CloudWatch, customers get enhanced
// visibility into the key performance statistics associated with their cache
// and can receive alarms if a part of their cache runs hot.
//
// See https://docs.aws.amazon.com/goto/WebAPI/elasticache-2015-02-02 for more information on this service.
//
// See elasticache package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/elasticache/
//
// Using the Client
//
// To contact Amazon ElastiCache with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon ElastiCache client ElastiCache for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/elasticache/#New
package elasticache
