// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package applicationinsights provides the client and types for making API
// requests to Amazon CloudWatch Application Insights.
//
// Amazon CloudWatch Application Insights is a service that helps you detect
// common problems with your applications. It enables you to pinpoint the source
// of issues in your applications (built with technologies such as Microsoft
// IIS, .NET, and Microsoft SQL Server), by providing key insights into detected
// problems.
//
// After you onboard your application, CloudWatch Application Insights identifies,
// recommends, and sets up metrics and logs. It continuously analyzes and correlates
// your metrics and logs for unusual behavior to surface actionable problems
// with your application. For example, if your application is slow and unresponsive
// and leading to HTTP 500 errors in your Application Load Balancer (ALB), Application
// Insights informs you that a memory pressure problem with your SQL Server
// database is occurring. It bases this analysis on impactful metrics and log
// errors.
//
// See https://docs.aws.amazon.com/goto/WebAPI/application-insights-2018-11-25 for more information on this service.
//
// See applicationinsights package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/applicationinsights/
//
// Using the Client
//
// To contact Amazon CloudWatch Application Insights with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon CloudWatch Application Insights client ApplicationInsights for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/applicationinsights/#New
package applicationinsights
