// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package computeoptimizer provides the client and types for making API
// requests to AWS Compute Optimizer.
//
// AWS Compute Optimizer is a service that analyzes the configuration and utilization
// metrics of your AWS compute resources, such as EC2 instances, Auto Scaling
// groups, AWS Lambda functions, and Amazon EBS volumes. It reports whether
// your resources are optimal, and generates optimization recommendations to
// reduce the cost and improve the performance of your workloads. Compute Optimizer
// also provides recent utilization metric data, as well as projected utilization
// metric data for the recommendations, which you can use to evaluate which
// recommendation provides the best price-performance trade-off. The analysis
// of your usage patterns can help you decide when to move or resize your running
// resources, and still meet your performance and capacity requirements. For
// more information about Compute Optimizer, including the required permissions
// to use the service, see the AWS Compute Optimizer User Guide (https://docs.aws.amazon.com/compute-optimizer/latest/ug/).
//
// See https://docs.aws.amazon.com/goto/WebAPI/compute-optimizer-2019-11-01 for more information on this service.
//
// See computeoptimizer package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/computeoptimizer/
//
// Using the Client
//
// To contact AWS Compute Optimizer with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Compute Optimizer client ComputeOptimizer for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/computeoptimizer/#New
package computeoptimizer
