// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package configservice provides the client and types for making API
// requests to AWS Config.
//
// AWS Config provides a way to keep track of the configurations of all the
// AWS resources associated with your AWS account. You can use AWS Config to
// get the current and historical configurations of each AWS resource and also
// to get information about the relationship between the resources. An AWS resource
// can be an Amazon Compute Cloud (Amazon EC2) instance, an Elastic Block Store
// (EBS) volume, an elastic network Interface (ENI), or a security group. For
// a complete list of resources currently supported by AWS Config, see Supported
// AWS Resources (https://docs.aws.amazon.com/config/latest/developerguide/resource-config-reference.html#supported-resources).
//
// You can access and manage AWS Config through the AWS Management Console,
// the AWS Command Line Interface (AWS CLI), the AWS Config API, or the AWS
// SDKs for AWS Config. This reference guide contains documentation for the
// AWS Config API and the AWS CLI commands that you can use to manage AWS Config.
// The AWS Config API uses the Signature Version 4 protocol for signing requests.
// For more information about how to sign a request with this protocol, see
// Signature Version 4 Signing Process (https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html).
// For detailed information about AWS Config features and their associated actions
// or commands, as well as how to work with AWS Management Console, see What
// Is AWS Config (https://docs.aws.amazon.com/config/latest/developerguide/WhatIsConfig.html)
// in the AWS Config Developer Guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/config-2014-11-12 for more information on this service.
//
// See configservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/configservice/
//
// Using the Client
//
// To contact AWS Config with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Config client ConfigService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/configservice/#New
package configservice
