// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package gamelift provides the client and types for making API
// requests to Amazon GameLift.
//
// GameLift provides solutions for hosting session-based multiplayer game servers
// in the cloud, including tools for deploying, operating, and scaling game
// servers. Built on AWS global computing infrastructure, GameLift helps you
// deliver high-performance, high-reliability, low-cost game servers while dynamically
// scaling your resource usage to meet player demand.
//
// About GameLift solutions
//
// Get more information on these GameLift solutions in the Amazon GameLift Developer
// Guide (http://docs.aws.amazon.com/gamelift/latest/developerguide/).
//
//    * Managed GameLift -- GameLift offers a fully managed service to set up
//    and maintain computing machines for hosting, manage game session and player
//    session life cycle, and handle security, storage, and performance tracking.
//    You can use automatic scaling tools to balance hosting costs against meeting
//    player demand., configure your game session management to minimize player
//    latency, or add FlexMatch for matchmaking.
//
//    * Managed GameLift with Realtime Servers – With GameLift Realtime Servers,
//    you can quickly configure and set up game servers for your game. Realtime
//    Servers provides a game server framework with core Amazon GameLift infrastructure
//    already built in.
//
//    * GameLift FleetIQ – Use GameLift FleetIQ as a standalone feature while
//    managing your own EC2 instances and Auto Scaling groups for game hosting.
//    GameLift FleetIQ provides optimizations that make low-cost Spot Instances
//    viable for game hosting.
//
// About this API Reference
//
// This reference guide describes the low-level service API for Amazon GameLift.
// You can find links to language-specific SDK guides and the AWS CLI reference
// with each operation and data type topic. Useful links:
//
//    * GameLift API operations listed by tasks (https://docs.aws.amazon.com/gamelift/latest/developerguide/reference-awssdk.html)
//
//    * GameLift tools and resources (https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-components.html)
//
// See https://docs.aws.amazon.com/goto/WebAPI/gamelift-2015-10-01 for more information on this service.
//
// See gamelift package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/gamelift/
//
// Using the Client
//
// To contact Amazon GameLift with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon GameLift client GameLift for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/gamelift/#New
package gamelift
