// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package fms provides the client and types for making API
// requests to Firewall Management Service.
//
// This is the AWS Firewall Manager API Reference. This guide is for developers
// who need detailed information about the AWS Firewall Manager API actions,
// data types, and errors. For detailed information about AWS Firewall Manager
// features, see the AWS Firewall Manager Developer Guide (https://docs.aws.amazon.com/waf/latest/developerguide/fms-chapter.html).
//
// Some API actions require explicit resource permissions. For information,
// see the developer guide topic Firewall Manager required permissions for API
// actions (https://docs.aws.amazon.com/waf/latest/developerguide/fms-api-permissions-ref.html).
//
// See https://docs.aws.amazon.com/goto/WebAPI/fms-2018-01-01 for more information on this service.
//
// See fms package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/fms/
//
// Using the Client
//
// To contact Firewall Management Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Firewall Management Service client FMS for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/fms/#New
package fms
