// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package iotevents provides the client and types for making API
// requests to AWS IoT Events.
//
// AWS IoT Events monitors your equipment or device fleets for failures or changes
// in operation, and triggers actions when such events occur. You can use AWS
// IoT Events API operations to create, read, update, and delete inputs and
// detector models, and to list their versions.
//
// See https://docs.aws.amazon.com/goto/WebAPI/iotevents-2018-07-27 for more information on this service.
//
// See iotevents package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotevents/
//
// Using the Client
//
// To contact AWS IoT Events with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS IoT Events client IoTEvents for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotevents/#New
package iotevents
