// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package health

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeConcurrentModificationException for service response error code
	// "ConcurrentModificationException".
	//
	// EnableHealthServiceAccessForOrganization (https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html)
	// is already in progress. Wait for the action to complete before trying again.
	// To get the current status, use the DescribeHealthServiceStatusForOrganization
	// (https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeHealthServiceStatusForOrganization.html)
	// operation.
	ErrCodeConcurrentModificationException = "ConcurrentModificationException"

	// ErrCodeInvalidPaginationToken for service response error code
	// "InvalidPaginationToken".
	//
	// The specified pagination token (nextToken) is not valid.
	ErrCodeInvalidPaginationToken = "InvalidPaginationToken"

	// ErrCodeUnsupportedLocale for service response error code
	// "UnsupportedLocale".
	//
	// The specified locale is not supported.
	ErrCodeUnsupportedLocale = "UnsupportedLocale"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"ConcurrentModificationException": newErrorConcurrentModificationException,
	"InvalidPaginationToken":          newErrorInvalidPaginationToken,
	"UnsupportedLocale":               newErrorUnsupportedLocale,
}
