// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package sns

const (

	// ErrCodeAuthorizationErrorException for service response error code
	// "AuthorizationError".
	//
	// Indicates that the user has been denied access to the requested resource.
	ErrCodeAuthorizationErrorException = "AuthorizationError"

	// ErrCodeConcurrentAccessException for service response error code
	// "ConcurrentAccess".
	//
	// Can't perform multiple operations on a tag simultaneously. Perform the operations
	// sequentially.
	ErrCodeConcurrentAccessException = "ConcurrentAccess"

	// ErrCodeEndpointDisabledException for service response error code
	// "EndpointDisabled".
	//
	// Exception error indicating endpoint disabled.
	ErrCodeEndpointDisabledException = "EndpointDisabled"

	// ErrCodeFilterPolicyLimitExceededException for service response error code
	// "FilterPolicyLimitExceeded".
	//
	// Indicates that the number of filter polices in your AWS account exceeds the
	// limit. To add more filter polices, submit an SNS Limit Increase case in the
	// AWS Support Center.
	ErrCodeFilterPolicyLimitExceededException = "FilterPolicyLimitExceeded"

	// ErrCodeInternalErrorException for service response error code
	// "InternalError".
	//
	// Indicates an internal service error.
	ErrCodeInternalErrorException = "InternalError"

	// ErrCodeInvalidParameterException for service response error code
	// "InvalidParameter".
	//
	// Indicates that a request parameter does not comply with the associated constraints.
	ErrCodeInvalidParameterException = "InvalidParameter"

	// ErrCodeInvalidParameterValueException for service response error code
	// "ParameterValueInvalid".
	//
	// Indicates that a request parameter does not comply with the associated constraints.
	ErrCodeInvalidParameterValueException = "ParameterValueInvalid"

	// ErrCodeInvalidSecurityException for service response error code
	// "InvalidSecurity".
	//
	// The credential signature isn't valid. You must use an HTTPS endpoint and
	// sign your request using Signature Version 4.
	ErrCodeInvalidSecurityException = "InvalidSecurity"

	// ErrCodeKMSAccessDeniedException for service response error code
	// "KMSAccessDenied".
	//
	// The ciphertext references a key that doesn't exist or that you don't have
	// access to.
	ErrCodeKMSAccessDeniedException = "KMSAccessDenied"

	// ErrCodeKMSDisabledException for service response error code
	// "KMSDisabled".
	//
	// The request was rejected because the specified customer master key (CMK)
	// isn't enabled.
	ErrCodeKMSDisabledException = "KMSDisabled"

	// ErrCodeKMSInvalidStateException for service response error code
	// "KMSInvalidState".
	//
	// The request was rejected because the state of the specified resource isn't
	// valid for this request. For more information, see How Key State Affects Use
	// of a Customer Master Key (https://docs.aws.amazon.com/kms/latest/developerguide/key-state.html)
	// in the AWS Key Management Service Developer Guide.
	ErrCodeKMSInvalidStateException = "KMSInvalidState"

	// ErrCodeKMSNotFoundException for service response error code
	// "KMSNotFound".
	//
	// The request was rejected because the specified entity or resource can't be
	// found.
	ErrCodeKMSNotFoundException = "KMSNotFound"

	// ErrCodeKMSOptInRequired for service response error code
	// "KMSOptInRequired".
	//
	// The AWS access key ID needs a subscription for the service.
	ErrCodeKMSOptInRequired = "KMSOptInRequired"

	// ErrCodeKMSThrottlingException for service response error code
	// "KMSThrottling".
	//
	// The request was denied due to request throttling. For more information about
	// throttling, see Limits (https://docs.aws.amazon.com/kms/latest/developerguide/limits.html#requests-per-second)
	// in the AWS Key Management Service Developer Guide.
	ErrCodeKMSThrottlingException = "KMSThrottling"

	// ErrCodeNotFoundException for service response error code
	// "NotFound".
	//
	// Indicates that the requested resource does not exist.
	ErrCodeNotFoundException = "NotFound"

	// ErrCodePlatformApplicationDisabledException for service response error code
	// "PlatformApplicationDisabled".
	//
	// Exception error indicating platform application disabled.
	ErrCodePlatformApplicationDisabledException = "PlatformApplicationDisabled"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFound".
	//
	// Can't tag resource. Verify that the topic exists.
	ErrCodeResourceNotFoundException = "ResourceNotFound"

	// ErrCodeStaleTagException for service response error code
	// "StaleTag".
	//
	// A tag has been added to a resource with the same ARN as a deleted resource.
	// Wait a short while and then retry the operation.
	ErrCodeStaleTagException = "StaleTag"

	// ErrCodeSubscriptionLimitExceededException for service response error code
	// "SubscriptionLimitExceeded".
	//
	// Indicates that the customer already owns the maximum allowed number of subscriptions.
	ErrCodeSubscriptionLimitExceededException = "SubscriptionLimitExceeded"

	// ErrCodeTagLimitExceededException for service response error code
	// "TagLimitExceeded".
	//
	// Can't add more than 50 tags to a topic.
	ErrCodeTagLimitExceededException = "TagLimitExceeded"

	// ErrCodeTagPolicyException for service response error code
	// "TagPolicy".
	//
	// The request doesn't comply with the IAM tag policy. Correct your request
	// and then retry it.
	ErrCodeTagPolicyException = "TagPolicy"

	// ErrCodeThrottledException for service response error code
	// "Throttled".
	//
	// Indicates that the rate at which requests have been submitted for this action
	// exceeds the limit for your account.
	ErrCodeThrottledException = "Throttled"

	// ErrCodeTopicLimitExceededException for service response error code
	// "TopicLimitExceeded".
	//
	// Indicates that the customer already owns the maximum allowed number of topics.
	ErrCodeTopicLimitExceededException = "TopicLimitExceeded"
)
