// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package ec2instanceconnect provides the client and types for making API
// requests to AWS EC2 Instance Connect.
//
// AWS EC2 Connect Service is a service that enables system administrators to
// publish temporary SSH keys to their EC2 instances in order to establish connections
// to their instances without leaving a permanent authentication option.
//
// See https://docs.aws.amazon.com/goto/WebAPI/ec2-instance-connect-2018-04-02 for more information on this service.
//
// See ec2instanceconnect package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/ec2instanceconnect/
//
// Using the Client
//
// To contact AWS EC2 Instance Connect with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS EC2 Instance Connect client EC2InstanceConnect for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/ec2instanceconnect/#New
package ec2instanceconnect
