// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package apigatewaymanagementapi provides the client and types for making API
// requests to AmazonApiGatewayManagementApi.
//
// The Amazon API Gateway Management API allows you to directly manage runtime
// aspects of your deployed APIs. To use it, you must explicitly set the SDK's
// endpoint to point to the endpoint of your deployed API. The endpoint will
// be of the form https://{api-id}.execute-api.{region}.amazonaws.com/{stage},
// or will be the endpoint corresponding to your API's custom domain and base
// path, if applicable.
//
// See https://docs.aws.amazon.com/goto/WebAPI/apigatewaymanagementapi-2018-11-29 for more information on this service.
//
// See apigatewaymanagementapi package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/apigatewaymanagementapi/
//
// Using the Client
//
// To contact AmazonApiGatewayManagementApi with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AmazonApiGatewayManagementApi client ApiGatewayManagementApi for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/apigatewaymanagementapi/#New
package apigatewaymanagementapi
