// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package datapipeline

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeInternalServiceError for service response error code
	// "InternalServiceError".
	//
	// An internal service error occurred.
	ErrCodeInternalServiceError = "InternalServiceError"

	// ErrCodeInvalidRequestException for service response error code
	// "InvalidRequestException".
	//
	// The request was not valid. Verify that your request was properly formatted,
	// that the signature was generated with the correct credentials, and that you
	// haven't exceeded any of the service limits for your account.
	ErrCodeInvalidRequestException = "InvalidRequestException"

	// ErrCodePipelineDeletedException for service response error code
	// "PipelineDeletedException".
	//
	// The specified pipeline has been deleted.
	ErrCodePipelineDeletedException = "PipelineDeletedException"

	// ErrCodePipelineNotFoundException for service response error code
	// "PipelineNotFoundException".
	//
	// The specified pipeline was not found. Verify that you used the correct user
	// and account identifiers.
	ErrCodePipelineNotFoundException = "PipelineNotFoundException"

	// ErrCodeTaskNotFoundException for service response error code
	// "TaskNotFoundException".
	//
	// The specified task was not found.
	ErrCodeTaskNotFoundException = "TaskNotFoundException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"InternalServiceError":      newErrorInternalServiceError,
	"InvalidRequestException":   newErrorInvalidRequestException,
	"PipelineDeletedException":  newErrorPipelineDeletedException,
	"PipelineNotFoundException": newErrorPipelineNotFoundException,
	"TaskNotFoundException":     newErrorTaskNotFoundException,
}
