// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package apigateway

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeBadRequestException for service response error code
	// "BadRequestException".
	//
	// The submitted request is not valid, for example, the input is incomplete
	// or incorrect. See the accompanying error message for details.
	ErrCodeBadRequestException = "BadRequestException"

	// ErrCodeConflictException for service response error code
	// "ConflictException".
	//
	// The request configuration has conflicts. For details, see the accompanying
	// error message.
	ErrCodeConflictException = "ConflictException"

	// ErrCodeLimitExceededException for service response error code
	// "LimitExceededException".
	//
	// The request exceeded the rate limit. Retry after the specified time period.
	ErrCodeLimitExceededException = "LimitExceededException"

	// ErrCodeNotFoundException for service response error code
	// "NotFoundException".
	//
	// The requested resource is not found. Make sure that the request URI is correct.
	ErrCodeNotFoundException = "NotFoundException"

	// ErrCodeServiceUnavailableException for service response error code
	// "ServiceUnavailableException".
	//
	// The requested service is not available. For details see the accompanying
	// error message. Retry after the specified time period.
	ErrCodeServiceUnavailableException = "ServiceUnavailableException"

	// ErrCodeTooManyRequestsException for service response error code
	// "TooManyRequestsException".
	//
	// The request has reached its throttling limit. Retry after the specified time
	// period.
	ErrCodeTooManyRequestsException = "TooManyRequestsException"

	// ErrCodeUnauthorizedException for service response error code
	// "UnauthorizedException".
	//
	// The request is denied because the caller has insufficient permissions.
	ErrCodeUnauthorizedException = "UnauthorizedException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"BadRequestException":         newErrorBadRequestException,
	"ConflictException":           newErrorConflictException,
	"LimitExceededException":      newErrorLimitExceededException,
	"NotFoundException":           newErrorNotFoundException,
	"ServiceUnavailableException": newErrorServiceUnavailableException,
	"TooManyRequestsException":    newErrorTooManyRequestsException,
	"UnauthorizedException":       newErrorUnauthorizedException,
}
