// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package qldb

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeInvalidParameterException for service response error code
	// "InvalidParameterException".
	//
	// One or more parameters in the request aren't valid.
	ErrCodeInvalidParameterException = "InvalidParameterException"

	// ErrCodeLimitExceededException for service response error code
	// "LimitExceededException".
	//
	// You have reached the limit on the maximum number of resources allowed.
	ErrCodeLimitExceededException = "LimitExceededException"

	// ErrCodeResourceAlreadyExistsException for service response error code
	// "ResourceAlreadyExistsException".
	//
	// The specified resource already exists.
	ErrCodeResourceAlreadyExistsException = "ResourceAlreadyExistsException"

	// ErrCodeResourceInUseException for service response error code
	// "ResourceInUseException".
	//
	// The specified resource can't be modified at this time.
	ErrCodeResourceInUseException = "ResourceInUseException"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFoundException".
	//
	// The specified resource doesn't exist.
	ErrCodeResourceNotFoundException = "ResourceNotFoundException"

	// ErrCodeResourcePreconditionNotMetException for service response error code
	// "ResourcePreconditionNotMetException".
	//
	// The operation failed because a condition wasn't satisfied in advance.
	ErrCodeResourcePreconditionNotMetException = "ResourcePreconditionNotMetException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"InvalidParameterException":           newErrorInvalidParameterException,
	"LimitExceededException":              newErrorLimitExceededException,
	"ResourceAlreadyExistsException":      newErrorResourceAlreadyExistsException,
	"ResourceInUseException":              newErrorResourceInUseException,
	"ResourceNotFoundException":           newErrorResourceNotFoundException,
	"ResourcePreconditionNotMetException": newErrorResourcePreconditionNotMetException,
}
