// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package cloudformation

const (

	// ErrCodeAlreadyExistsException for service response error code
	// "AlreadyExistsException".
	//
	// The resource with the name requested already exists.
	ErrCodeAlreadyExistsException = "AlreadyExistsException"

	// ErrCodeCFNRegistryException for service response error code
	// "CFNRegistryException".
	//
	// An error occurred during a CloudFormation registry operation.
	ErrCodeCFNRegistryException = "CFNRegistryException"

	// ErrCodeChangeSetNotFoundException for service response error code
	// "ChangeSetNotFound".
	//
	// The specified change set name or ID doesn't exit. To view valid change sets
	// for a stack, use the ListChangeSets action.
	ErrCodeChangeSetNotFoundException = "ChangeSetNotFound"

	// ErrCodeCreatedButModifiedException for service response error code
	// "CreatedButModifiedException".
	//
	// The specified resource exists, but has been changed.
	ErrCodeCreatedButModifiedException = "CreatedButModifiedException"

	// ErrCodeInsufficientCapabilitiesException for service response error code
	// "InsufficientCapabilitiesException".
	//
	// The template contains resources with capabilities that weren't specified
	// in the Capabilities parameter.
	ErrCodeInsufficientCapabilitiesException = "InsufficientCapabilitiesException"

	// ErrCodeInvalidChangeSetStatusException for service response error code
	// "InvalidChangeSetStatus".
	//
	// The specified change set can't be used to update the stack. For example,
	// the change set status might be CREATE_IN_PROGRESS, or the stack status might
	// be UPDATE_IN_PROGRESS.
	ErrCodeInvalidChangeSetStatusException = "InvalidChangeSetStatus"

	// ErrCodeInvalidOperationException for service response error code
	// "InvalidOperationException".
	//
	// The specified operation isn't valid.
	ErrCodeInvalidOperationException = "InvalidOperationException"

	// ErrCodeInvalidStateTransitionException for service response error code
	// "InvalidStateTransition".
	//
	// Error reserved for use by the CloudFormation CLI (https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/what-is-cloudformation-cli.html).
	// CloudFormation does not return this error to users.
	ErrCodeInvalidStateTransitionException = "InvalidStateTransition"

	// ErrCodeLimitExceededException for service response error code
	// "LimitExceededException".
	//
	// The quota for the resource has already been reached.
	//
	// For information on resource and stack limitations, see Limits (https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html)
	// in the AWS CloudFormation User Guide.
	ErrCodeLimitExceededException = "LimitExceededException"

	// ErrCodeNameAlreadyExistsException for service response error code
	// "NameAlreadyExistsException".
	//
	// The specified name is already in use.
	ErrCodeNameAlreadyExistsException = "NameAlreadyExistsException"

	// ErrCodeOperationIdAlreadyExistsException for service response error code
	// "OperationIdAlreadyExistsException".
	//
	// The specified operation ID already exists.
	ErrCodeOperationIdAlreadyExistsException = "OperationIdAlreadyExistsException"

	// ErrCodeOperationInProgressException for service response error code
	// "OperationInProgressException".
	//
	// Another operation is currently in progress for this stack set. Only one operation
	// can be performed for a stack set at a given time.
	ErrCodeOperationInProgressException = "OperationInProgressException"

	// ErrCodeOperationNotFoundException for service response error code
	// "OperationNotFoundException".
	//
	// The specified ID refers to an operation that doesn't exist.
	ErrCodeOperationNotFoundException = "OperationNotFoundException"

	// ErrCodeOperationStatusCheckFailedException for service response error code
	// "ConditionalCheckFailed".
	//
	// Error reserved for use by the CloudFormation CLI (https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/what-is-cloudformation-cli.html).
	// CloudFormation does not return this error to users.
	ErrCodeOperationStatusCheckFailedException = "ConditionalCheckFailed"

	// ErrCodeStackInstanceNotFoundException for service response error code
	// "StackInstanceNotFoundException".
	//
	// The specified stack instance doesn't exist.
	ErrCodeStackInstanceNotFoundException = "StackInstanceNotFoundException"

	// ErrCodeStackSetNotEmptyException for service response error code
	// "StackSetNotEmptyException".
	//
	// You can't yet delete this stack set, because it still contains one or more
	// stack instances. Delete all stack instances from the stack set before deleting
	// the stack set.
	ErrCodeStackSetNotEmptyException = "StackSetNotEmptyException"

	// ErrCodeStackSetNotFoundException for service response error code
	// "StackSetNotFoundException".
	//
	// The specified stack set doesn't exist.
	ErrCodeStackSetNotFoundException = "StackSetNotFoundException"

	// ErrCodeStaleRequestException for service response error code
	// "StaleRequestException".
	//
	// Another operation has been performed on this stack set since the specified
	// operation was performed.
	ErrCodeStaleRequestException = "StaleRequestException"

	// ErrCodeTokenAlreadyExistsException for service response error code
	// "TokenAlreadyExistsException".
	//
	// A client request token already exists.
	ErrCodeTokenAlreadyExistsException = "TokenAlreadyExistsException"

	// ErrCodeTypeNotFoundException for service response error code
	// "TypeNotFoundException".
	//
	// The specified type does not exist in the CloudFormation registry.
	ErrCodeTypeNotFoundException = "TypeNotFoundException"
)
