// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package servicediscovery provides the client and types for making API
// requests to AWS Cloud Map.
//
// AWS Cloud Map lets you configure public DNS, private DNS, or HTTP namespaces
// that your microservice applications run in. When an instance of the service
// becomes available, you can call the AWS Cloud Map API to register the instance
// with AWS Cloud Map. For public or private DNS namespaces, AWS Cloud Map automatically
// creates DNS records and an optional health check. Clients that submit public
// or private DNS queries, or HTTP requests, for the service receive an answer
// that contains up to eight healthy records.
//
// See https://docs.aws.amazon.com/goto/WebAPI/servicediscovery-2017-03-14 for more information on this service.
//
// See servicediscovery package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/servicediscovery/
//
// Using the Client
//
// To contact AWS Cloud Map with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Cloud Map client ServiceDiscovery for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/servicediscovery/#New
package servicediscovery
