// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package s3control

const (

	// ErrCodeBadRequestException for service response error code
	// "BadRequestException".
	ErrCodeBadRequestException = "BadRequestException"

	// ErrCodeBucketAlreadyExists for service response error code
	// "BucketAlreadyExists".
	//
	// The requested Outposts bucket name is not available. The bucket namespace
	// is shared by all users of the AWS Outposts in this Region. Select a different
	// name and try again.
	ErrCodeBucketAlreadyExists = "BucketAlreadyExists"

	// ErrCodeBucketAlreadyOwnedByYou for service response error code
	// "BucketAlreadyOwnedByYou".
	//
	// The Outposts bucket you tried to create already exists, and you own it.
	ErrCodeBucketAlreadyOwnedByYou = "BucketAlreadyOwnedByYou"

	// ErrCodeIdempotencyException for service response error code
	// "IdempotencyException".
	ErrCodeIdempotencyException = "IdempotencyException"

	// ErrCodeInternalServiceException for service response error code
	// "InternalServiceException".
	ErrCodeInternalServiceException = "InternalServiceException"

	// ErrCodeInvalidNextTokenException for service response error code
	// "InvalidNextTokenException".
	ErrCodeInvalidNextTokenException = "InvalidNextTokenException"

	// ErrCodeInvalidRequestException for service response error code
	// "InvalidRequestException".
	ErrCodeInvalidRequestException = "InvalidRequestException"

	// ErrCodeJobStatusException for service response error code
	// "JobStatusException".
	ErrCodeJobStatusException = "JobStatusException"

	// ErrCodeNoSuchPublicAccessBlockConfiguration for service response error code
	// "NoSuchPublicAccessBlockConfiguration".
	//
	// Amazon S3 throws this exception if you make a GetPublicAccessBlock request
	// against an account that doesn't have a PublicAccessBlockConfiguration set.
	ErrCodeNoSuchPublicAccessBlockConfiguration = "NoSuchPublicAccessBlockConfiguration"

	// ErrCodeNotFoundException for service response error code
	// "NotFoundException".
	ErrCodeNotFoundException = "NotFoundException"

	// ErrCodeTooManyRequestsException for service response error code
	// "TooManyRequestsException".
	ErrCodeTooManyRequestsException = "TooManyRequestsException"

	// ErrCodeTooManyTagsException for service response error code
	// "TooManyTagsException".
	//
	// Amazon S3 throws this exception if you have too many tags in your tag set.
	ErrCodeTooManyTagsException = "TooManyTagsException"
)
