// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package restxmlservice

const (

	// ErrCodeExceptionEvent for service response error code
	// "ExceptionEvent".
	ErrCodeExceptionEvent = "ExceptionEvent"

	// ErrCodeExceptionEvent2 for service response error code
	// "ExceptionEvent2".
	ErrCodeExceptionEvent2 = "ExceptionEvent2"
)
