// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package codecommit

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeActorDoesNotExistException for service response error code
	// "ActorDoesNotExistException".
	//
	// The specified Amazon Resource Name (ARN) does not exist in the AWS account.
	ErrCodeActorDoesNotExistException = "ActorDoesNotExistException"

	// ErrCodeApprovalRuleContentRequiredException for service response error code
	// "ApprovalRuleContentRequiredException".
	//
	// The content for the approval rule is empty. You must provide some content
	// for an approval rule. The content cannot be null.
	ErrCodeApprovalRuleContentRequiredException = "ApprovalRuleContentRequiredException"

	// ErrCodeApprovalRuleDoesNotExistException for service response error code
	// "ApprovalRuleDoesNotExistException".
	//
	// The specified approval rule does not exist.
	ErrCodeApprovalRuleDoesNotExistException = "ApprovalRuleDoesNotExistException"

	// ErrCodeApprovalRuleNameAlreadyExistsException for service response error code
	// "ApprovalRuleNameAlreadyExistsException".
	//
	// An approval rule with that name already exists. Approval rule names must
	// be unique within the scope of a pull request.
	ErrCodeApprovalRuleNameAlreadyExistsException = "ApprovalRuleNameAlreadyExistsException"

	// ErrCodeApprovalRuleNameRequiredException for service response error code
	// "ApprovalRuleNameRequiredException".
	//
	// An approval rule name is required, but was not specified.
	ErrCodeApprovalRuleNameRequiredException = "ApprovalRuleNameRequiredException"

	// ErrCodeApprovalRuleTemplateContentRequiredException for service response error code
	// "ApprovalRuleTemplateContentRequiredException".
	//
	// The content for the approval rule template is empty. You must provide some
	// content for an approval rule template. The content cannot be null.
	ErrCodeApprovalRuleTemplateContentRequiredException = "ApprovalRuleTemplateContentRequiredException"

	// ErrCodeApprovalRuleTemplateDoesNotExistException for service response error code
	// "ApprovalRuleTemplateDoesNotExistException".
	//
	// The specified approval rule template does not exist. Verify that the name
	// is correct and that you are signed in to the AWS Region where the template
	// was created, and then try again.
	ErrCodeApprovalRuleTemplateDoesNotExistException = "ApprovalRuleTemplateDoesNotExistException"

	// ErrCodeApprovalRuleTemplateInUseException for service response error code
	// "ApprovalRuleTemplateInUseException".
	//
	// The approval rule template is associated with one or more repositories. You
	// cannot delete a template that is associated with a repository. Remove all
	// associations, and then try again.
	ErrCodeApprovalRuleTemplateInUseException = "ApprovalRuleTemplateInUseException"

	// ErrCodeApprovalRuleTemplateNameAlreadyExistsException for service response error code
	// "ApprovalRuleTemplateNameAlreadyExistsException".
	//
	// You cannot create an approval rule template with that name because a template
	// with that name already exists in this AWS Region for your AWS account. Approval
	// rule template names must be unique.
	ErrCodeApprovalRuleTemplateNameAlreadyExistsException = "ApprovalRuleTemplateNameAlreadyExistsException"

	// ErrCodeApprovalRuleTemplateNameRequiredException for service response error code
	// "ApprovalRuleTemplateNameRequiredException".
	//
	// An approval rule template name is required, but was not specified.
	ErrCodeApprovalRuleTemplateNameRequiredException = "ApprovalRuleTemplateNameRequiredException"

	// ErrCodeApprovalStateRequiredException for service response error code
	// "ApprovalStateRequiredException".
	//
	// An approval state is required, but was not specified.
	ErrCodeApprovalStateRequiredException = "ApprovalStateRequiredException"

	// ErrCodeAuthorDoesNotExistException for service response error code
	// "AuthorDoesNotExistException".
	//
	// The specified Amazon Resource Name (ARN) does not exist in the AWS account.
	ErrCodeAuthorDoesNotExistException = "AuthorDoesNotExistException"

	// ErrCodeBeforeCommitIdAndAfterCommitIdAreSameException for service response error code
	// "BeforeCommitIdAndAfterCommitIdAreSameException".
	//
	// The before commit ID and the after commit ID are the same, which is not valid.
	// The before commit ID and the after commit ID must be different commit IDs.
	ErrCodeBeforeCommitIdAndAfterCommitIdAreSameException = "BeforeCommitIdAndAfterCommitIdAreSameException"

	// ErrCodeBlobIdDoesNotExistException for service response error code
	// "BlobIdDoesNotExistException".
	//
	// The specified blob does not exist.
	ErrCodeBlobIdDoesNotExistException = "BlobIdDoesNotExistException"

	// ErrCodeBlobIdRequiredException for service response error code
	// "BlobIdRequiredException".
	//
	// A blob ID is required, but was not specified.
	ErrCodeBlobIdRequiredException = "BlobIdRequiredException"

	// ErrCodeBranchDoesNotExistException for service response error code
	// "BranchDoesNotExistException".
	//
	// The specified branch does not exist.
	ErrCodeBranchDoesNotExistException = "BranchDoesNotExistException"

	// ErrCodeBranchNameExistsException for service response error code
	// "BranchNameExistsException".
	//
	// Cannot create the branch with the specified name because the commit conflicts
	// with an existing branch with the same name. Branch names must be unique.
	ErrCodeBranchNameExistsException = "BranchNameExistsException"

	// ErrCodeBranchNameIsTagNameException for service response error code
	// "BranchNameIsTagNameException".
	//
	// The specified branch name is not valid because it is a tag name. Enter the
	// name of a branch in the repository. For a list of valid branch names, use
	// ListBranches.
	ErrCodeBranchNameIsTagNameException = "BranchNameIsTagNameException"

	// ErrCodeBranchNameRequiredException for service response error code
	// "BranchNameRequiredException".
	//
	// A branch name is required, but was not specified.
	ErrCodeBranchNameRequiredException = "BranchNameRequiredException"

	// ErrCodeCannotDeleteApprovalRuleFromTemplateException for service response error code
	// "CannotDeleteApprovalRuleFromTemplateException".
	//
	// The approval rule cannot be deleted from the pull request because it was
	// created by an approval rule template and applied to the pull request automatically.
	ErrCodeCannotDeleteApprovalRuleFromTemplateException = "CannotDeleteApprovalRuleFromTemplateException"

	// ErrCodeCannotModifyApprovalRuleFromTemplateException for service response error code
	// "CannotModifyApprovalRuleFromTemplateException".
	//
	// The approval rule cannot be modified for the pull request because it was
	// created by an approval rule template and applied to the pull request automatically.
	ErrCodeCannotModifyApprovalRuleFromTemplateException = "CannotModifyApprovalRuleFromTemplateException"

	// ErrCodeClientRequestTokenRequiredException for service response error code
	// "ClientRequestTokenRequiredException".
	//
	// A client request token is required. A client request token is an unique,
	// client-generated idempotency token that, when provided in a request, ensures
	// the request cannot be repeated with a changed parameter. If a request is
	// received with the same parameters and a token is included, the request returns
	// information about the initial request that used that token.
	ErrCodeClientRequestTokenRequiredException = "ClientRequestTokenRequiredException"

	// ErrCodeCommentContentRequiredException for service response error code
	// "CommentContentRequiredException".
	//
	// The comment is empty. You must provide some content for a comment. The content
	// cannot be null.
	ErrCodeCommentContentRequiredException = "CommentContentRequiredException"

	// ErrCodeCommentContentSizeLimitExceededException for service response error code
	// "CommentContentSizeLimitExceededException".
	//
	// The comment is too large. Comments are limited to 1,000 characters.
	ErrCodeCommentContentSizeLimitExceededException = "CommentContentSizeLimitExceededException"

	// ErrCodeCommentDeletedException for service response error code
	// "CommentDeletedException".
	//
	// This comment has already been deleted. You cannot edit or delete a deleted
	// comment.
	ErrCodeCommentDeletedException = "CommentDeletedException"

	// ErrCodeCommentDoesNotExistException for service response error code
	// "CommentDoesNotExistException".
	//
	// No comment exists with the provided ID. Verify that you have used the correct
	// ID, and then try again.
	ErrCodeCommentDoesNotExistException = "CommentDoesNotExistException"

	// ErrCodeCommentIdRequiredException for service response error code
	// "CommentIdRequiredException".
	//
	// The comment ID is missing or null. A comment ID is required.
	ErrCodeCommentIdRequiredException = "CommentIdRequiredException"

	// ErrCodeCommentNotCreatedByCallerException for service response error code
	// "CommentNotCreatedByCallerException".
	//
	// You cannot modify or delete this comment. Only comment authors can modify
	// or delete their comments.
	ErrCodeCommentNotCreatedByCallerException = "CommentNotCreatedByCallerException"

	// ErrCodeCommitDoesNotExistException for service response error code
	// "CommitDoesNotExistException".
	//
	// The specified commit does not exist or no commit was specified, and the specified
	// repository has no default branch.
	ErrCodeCommitDoesNotExistException = "CommitDoesNotExistException"

	// ErrCodeCommitIdDoesNotExistException for service response error code
	// "CommitIdDoesNotExistException".
	//
	// The specified commit ID does not exist.
	ErrCodeCommitIdDoesNotExistException = "CommitIdDoesNotExistException"

	// ErrCodeCommitIdRequiredException for service response error code
	// "CommitIdRequiredException".
	//
	// A commit ID was not specified.
	ErrCodeCommitIdRequiredException = "CommitIdRequiredException"

	// ErrCodeCommitIdsLimitExceededException for service response error code
	// "CommitIdsLimitExceededException".
	//
	// The maximum number of allowed commit IDs in a batch request is 100. Verify
	// that your batch requests contains no more than 100 commit IDs, and then try
	// again.
	ErrCodeCommitIdsLimitExceededException = "CommitIdsLimitExceededException"

	// ErrCodeCommitIdsListRequiredException for service response error code
	// "CommitIdsListRequiredException".
	//
	// A list of commit IDs is required, but was either not specified or the list
	// was empty.
	ErrCodeCommitIdsListRequiredException = "CommitIdsListRequiredException"

	// ErrCodeCommitMessageLengthExceededException for service response error code
	// "CommitMessageLengthExceededException".
	//
	// The commit message is too long. Provide a shorter string.
	ErrCodeCommitMessageLengthExceededException = "CommitMessageLengthExceededException"

	// ErrCodeCommitRequiredException for service response error code
	// "CommitRequiredException".
	//
	// A commit was not specified.
	ErrCodeCommitRequiredException = "CommitRequiredException"

	// ErrCodeConcurrentReferenceUpdateException for service response error code
	// "ConcurrentReferenceUpdateException".
	//
	// The merge cannot be completed because the target branch has been modified.
	// Another user might have modified the target branch while the merge was in
	// progress. Wait a few minutes, and then try again.
	ErrCodeConcurrentReferenceUpdateException = "ConcurrentReferenceUpdateException"

	// ErrCodeDefaultBranchCannotBeDeletedException for service response error code
	// "DefaultBranchCannotBeDeletedException".
	//
	// The specified branch is the default branch for the repository, and cannot
	// be deleted. To delete this branch, you must first set another branch as the
	// default branch.
	ErrCodeDefaultBranchCannotBeDeletedException = "DefaultBranchCannotBeDeletedException"

	// ErrCodeDirectoryNameConflictsWithFileNameException for service response error code
	// "DirectoryNameConflictsWithFileNameException".
	//
	// A file cannot be added to the repository because the specified path name
	// has the same name as a file that already exists in this repository. Either
	// provide a different name for the file, or specify a different path for the
	// file.
	ErrCodeDirectoryNameConflictsWithFileNameException = "DirectoryNameConflictsWithFileNameException"

	// ErrCodeEncryptionIntegrityChecksFailedException for service response error code
	// "EncryptionIntegrityChecksFailedException".
	//
	// An encryption integrity check failed.
	ErrCodeEncryptionIntegrityChecksFailedException = "EncryptionIntegrityChecksFailedException"

	// ErrCodeEncryptionKeyAccessDeniedException for service response error code
	// "EncryptionKeyAccessDeniedException".
	//
	// An encryption key could not be accessed.
	ErrCodeEncryptionKeyAccessDeniedException = "EncryptionKeyAccessDeniedException"

	// ErrCodeEncryptionKeyDisabledException for service response error code
	// "EncryptionKeyDisabledException".
	//
	// The encryption key is disabled.
	ErrCodeEncryptionKeyDisabledException = "EncryptionKeyDisabledException"

	// ErrCodeEncryptionKeyNotFoundException for service response error code
	// "EncryptionKeyNotFoundException".
	//
	// No encryption key was found.
	ErrCodeEncryptionKeyNotFoundException = "EncryptionKeyNotFoundException"

	// ErrCodeEncryptionKeyUnavailableException for service response error code
	// "EncryptionKeyUnavailableException".
	//
	// The encryption key is not available.
	ErrCodeEncryptionKeyUnavailableException = "EncryptionKeyUnavailableException"

	// ErrCodeFileContentAndSourceFileSpecifiedException for service response error code
	// "FileContentAndSourceFileSpecifiedException".
	//
	// The commit cannot be created because both a source file and file content
	// have been specified for the same file. You cannot provide both. Either specify
	// a source file or provide the file content directly.
	ErrCodeFileContentAndSourceFileSpecifiedException = "FileContentAndSourceFileSpecifiedException"

	// ErrCodeFileContentRequiredException for service response error code
	// "FileContentRequiredException".
	//
	// The file cannot be added because it is empty. Empty files cannot be added
	// to the repository with this API.
	ErrCodeFileContentRequiredException = "FileContentRequiredException"

	// ErrCodeFileContentSizeLimitExceededException for service response error code
	// "FileContentSizeLimitExceededException".
	//
	// The file cannot be added because it is too large. The maximum file size is
	// 6 MB, and the combined file content change size is 7 MB. Consider making
	// these changes using a Git client.
	ErrCodeFileContentSizeLimitExceededException = "FileContentSizeLimitExceededException"

	// ErrCodeFileDoesNotExistException for service response error code
	// "FileDoesNotExistException".
	//
	// The specified file does not exist. Verify that you have used the correct
	// file name, full path, and extension.
	ErrCodeFileDoesNotExistException = "FileDoesNotExistException"

	// ErrCodeFileEntryRequiredException for service response error code
	// "FileEntryRequiredException".
	//
	// The commit cannot be created because no files have been specified as added,
	// updated, or changed (PutFile or DeleteFile) for the commit.
	ErrCodeFileEntryRequiredException = "FileEntryRequiredException"

	// ErrCodeFileModeRequiredException for service response error code
	// "FileModeRequiredException".
	//
	// The commit cannot be created because no file mode has been specified. A file
	// mode is required to update mode permissions for a file.
	ErrCodeFileModeRequiredException = "FileModeRequiredException"

	// ErrCodeFileNameConflictsWithDirectoryNameException for service response error code
	// "FileNameConflictsWithDirectoryNameException".
	//
	// A file cannot be added to the repository because the specified file name
	// has the same name as a directory in this repository. Either provide another
	// name for the file, or add the file in a directory that does not match the
	// file name.
	ErrCodeFileNameConflictsWithDirectoryNameException = "FileNameConflictsWithDirectoryNameException"

	// ErrCodeFilePathConflictsWithSubmodulePathException for service response error code
	// "FilePathConflictsWithSubmodulePathException".
	//
	// The commit cannot be created because a specified file path points to a submodule.
	// Verify that the destination files have valid file paths that do not point
	// to a submodule.
	ErrCodeFilePathConflictsWithSubmodulePathException = "FilePathConflictsWithSubmodulePathException"

	// ErrCodeFileTooLargeException for service response error code
	// "FileTooLargeException".
	//
	// The specified file exceeds the file size limit for AWS CodeCommit. For more
	// information about limits in AWS CodeCommit, see AWS CodeCommit User Guide
	// (https://docs.aws.amazon.com/codecommit/latest/userguide/limits.html).
	ErrCodeFileTooLargeException = "FileTooLargeException"

	// ErrCodeFolderContentSizeLimitExceededException for service response error code
	// "FolderContentSizeLimitExceededException".
	//
	// The commit cannot be created because at least one of the overall changes
	// in the commit results in a folder whose contents exceed the limit of 6 MB.
	// Either reduce the number and size of your changes, or split the changes across
	// multiple folders.
	ErrCodeFolderContentSizeLimitExceededException = "FolderContentSizeLimitExceededException"

	// ErrCodeFolderDoesNotExistException for service response error code
	// "FolderDoesNotExistException".
	//
	// The specified folder does not exist. Either the folder name is not correct,
	// or you did not enter the full path to the folder.
	ErrCodeFolderDoesNotExistException = "FolderDoesNotExistException"

	// ErrCodeIdempotencyParameterMismatchException for service response error code
	// "IdempotencyParameterMismatchException".
	//
	// The client request token is not valid. Either the token is not in a valid
	// format, or the token has been used in a previous request and cannot be reused.
	ErrCodeIdempotencyParameterMismatchException = "IdempotencyParameterMismatchException"

	// ErrCodeInvalidActorArnException for service response error code
	// "InvalidActorArnException".
	//
	// The Amazon Resource Name (ARN) is not valid. Make sure that you have provided
	// the full ARN for the user who initiated the change for the pull request,
	// and then try again.
	ErrCodeInvalidActorArnException = "InvalidActorArnException"

	// ErrCodeInvalidApprovalRuleContentException for service response error code
	// "InvalidApprovalRuleContentException".
	//
	// The content for the approval rule is not valid.
	ErrCodeInvalidApprovalRuleContentException = "InvalidApprovalRuleContentException"

	// ErrCodeInvalidApprovalRuleNameException for service response error code
	// "InvalidApprovalRuleNameException".
	//
	// The name for the approval rule is not valid.
	ErrCodeInvalidApprovalRuleNameException = "InvalidApprovalRuleNameException"

	// ErrCodeInvalidApprovalRuleTemplateContentException for service response error code
	// "InvalidApprovalRuleTemplateContentException".
	//
	// The content of the approval rule template is not valid.
	ErrCodeInvalidApprovalRuleTemplateContentException = "InvalidApprovalRuleTemplateContentException"

	// ErrCodeInvalidApprovalRuleTemplateDescriptionException for service response error code
	// "InvalidApprovalRuleTemplateDescriptionException".
	//
	// The description for the approval rule template is not valid because it exceeds
	// the maximum characters allowed for a description. For more information about
	// limits in AWS CodeCommit, see AWS CodeCommit User Guide (https://docs.aws.amazon.com/codecommit/latest/userguide/limits.html).
	ErrCodeInvalidApprovalRuleTemplateDescriptionException = "InvalidApprovalRuleTemplateDescriptionException"

	// ErrCodeInvalidApprovalRuleTemplateNameException for service response error code
	// "InvalidApprovalRuleTemplateNameException".
	//
	// The name of the approval rule template is not valid. Template names must
	// be between 1 and 100 valid characters in length. For more information about
	// limits in AWS CodeCommit, see AWS CodeCommit User Guide (https://docs.aws.amazon.com/codecommit/latest/userguide/limits.html).
	ErrCodeInvalidApprovalRuleTemplateNameException = "InvalidApprovalRuleTemplateNameException"

	// ErrCodeInvalidApprovalStateException for service response error code
	// "InvalidApprovalStateException".
	//
	// The state for the approval is not valid. Valid values include APPROVE and
	// REVOKE.
	ErrCodeInvalidApprovalStateException = "InvalidApprovalStateException"

	// ErrCodeInvalidAuthorArnException for service response error code
	// "InvalidAuthorArnException".
	//
	// The Amazon Resource Name (ARN) is not valid. Make sure that you have provided
	// the full ARN for the author of the pull request, and then try again.
	ErrCodeInvalidAuthorArnException = "InvalidAuthorArnException"

	// ErrCodeInvalidBlobIdException for service response error code
	// "InvalidBlobIdException".
	//
	// The specified blob is not valid.
	ErrCodeInvalidBlobIdException = "InvalidBlobIdException"

	// ErrCodeInvalidBranchNameException for service response error code
	// "InvalidBranchNameException".
	//
	// The specified reference name is not valid.
	ErrCodeInvalidBranchNameException = "InvalidBranchNameException"

	// ErrCodeInvalidClientRequestTokenException for service response error code
	// "InvalidClientRequestTokenException".
	//
	// The client request token is not valid.
	ErrCodeInvalidClientRequestTokenException = "InvalidClientRequestTokenException"

	// ErrCodeInvalidCommentIdException for service response error code
	// "InvalidCommentIdException".
	//
	// The comment ID is not in a valid format. Make sure that you have provided
	// the full comment ID.
	ErrCodeInvalidCommentIdException = "InvalidCommentIdException"

	// ErrCodeInvalidCommitException for service response error code
	// "InvalidCommitException".
	//
	// The specified commit is not valid.
	ErrCodeInvalidCommitException = "InvalidCommitException"

	// ErrCodeInvalidCommitIdException for service response error code
	// "InvalidCommitIdException".
	//
	// The specified commit ID is not valid.
	ErrCodeInvalidCommitIdException = "InvalidCommitIdException"

	// ErrCodeInvalidConflictDetailLevelException for service response error code
	// "InvalidConflictDetailLevelException".
	//
	// The specified conflict detail level is not valid.
	ErrCodeInvalidConflictDetailLevelException = "InvalidConflictDetailLevelException"

	// ErrCodeInvalidConflictResolutionException for service response error code
	// "InvalidConflictResolutionException".
	//
	// The specified conflict resolution list is not valid.
	ErrCodeInvalidConflictResolutionException = "InvalidConflictResolutionException"

	// ErrCodeInvalidConflictResolutionStrategyException for service response error code
	// "InvalidConflictResolutionStrategyException".
	//
	// The specified conflict resolution strategy is not valid.
	ErrCodeInvalidConflictResolutionStrategyException = "InvalidConflictResolutionStrategyException"

	// ErrCodeInvalidContinuationTokenException for service response error code
	// "InvalidContinuationTokenException".
	//
	// The specified continuation token is not valid.
	ErrCodeInvalidContinuationTokenException = "InvalidContinuationTokenException"

	// ErrCodeInvalidDeletionParameterException for service response error code
	// "InvalidDeletionParameterException".
	//
	// The specified deletion parameter is not valid.
	ErrCodeInvalidDeletionParameterException = "InvalidDeletionParameterException"

	// ErrCodeInvalidDescriptionException for service response error code
	// "InvalidDescriptionException".
	//
	// The pull request description is not valid. Descriptions cannot be more than
	// 1,000 characters.
	ErrCodeInvalidDescriptionException = "InvalidDescriptionException"

	// ErrCodeInvalidDestinationCommitSpecifierException for service response error code
	// "InvalidDestinationCommitSpecifierException".
	//
	// The destination commit specifier is not valid. You must provide a valid branch
	// name, tag, or full commit ID.
	ErrCodeInvalidDestinationCommitSpecifierException = "InvalidDestinationCommitSpecifierException"

	// ErrCodeInvalidEmailException for service response error code
	// "InvalidEmailException".
	//
	// The specified email address either contains one or more characters that are
	// not allowed, or it exceeds the maximum number of characters allowed for an
	// email address.
	ErrCodeInvalidEmailException = "InvalidEmailException"

	// ErrCodeInvalidFileLocationException for service response error code
	// "InvalidFileLocationException".
	//
	// The location of the file is not valid. Make sure that you include the file
	// name and extension.
	ErrCodeInvalidFileLocationException = "InvalidFileLocationException"

	// ErrCodeInvalidFileModeException for service response error code
	// "InvalidFileModeException".
	//
	// The specified file mode permission is not valid. For a list of valid file
	// mode permissions, see PutFile.
	ErrCodeInvalidFileModeException = "InvalidFileModeException"

	// ErrCodeInvalidFilePositionException for service response error code
	// "InvalidFilePositionException".
	//
	// The position is not valid. Make sure that the line number exists in the version
	// of the file you want to comment on.
	ErrCodeInvalidFilePositionException = "InvalidFilePositionException"

	// ErrCodeInvalidMaxConflictFilesException for service response error code
	// "InvalidMaxConflictFilesException".
	//
	// The specified value for the number of conflict files to return is not valid.
	ErrCodeInvalidMaxConflictFilesException = "InvalidMaxConflictFilesException"

	// ErrCodeInvalidMaxMergeHunksException for service response error code
	// "InvalidMaxMergeHunksException".
	//
	// The specified value for the number of merge hunks to return is not valid.
	ErrCodeInvalidMaxMergeHunksException = "InvalidMaxMergeHunksException"

	// ErrCodeInvalidMaxResultsException for service response error code
	// "InvalidMaxResultsException".
	//
	// The specified number of maximum results is not valid.
	ErrCodeInvalidMaxResultsException = "InvalidMaxResultsException"

	// ErrCodeInvalidMergeOptionException for service response error code
	// "InvalidMergeOptionException".
	//
	// The specified merge option is not valid for this operation. Not all merge
	// strategies are supported for all operations.
	ErrCodeInvalidMergeOptionException = "InvalidMergeOptionException"

	// ErrCodeInvalidOrderException for service response error code
	// "InvalidOrderException".
	//
	// The specified sort order is not valid.
	ErrCodeInvalidOrderException = "InvalidOrderException"

	// ErrCodeInvalidOverrideStatusException for service response error code
	// "InvalidOverrideStatusException".
	//
	// The override status is not valid. Valid statuses are OVERRIDE and REVOKE.
	ErrCodeInvalidOverrideStatusException = "InvalidOverrideStatusException"

	// ErrCodeInvalidParentCommitIdException for service response error code
	// "InvalidParentCommitIdException".
	//
	// The parent commit ID is not valid. The commit ID cannot be empty, and must
	// match the head commit ID for the branch of the repository where you want
	// to add or update a file.
	ErrCodeInvalidParentCommitIdException = "InvalidParentCommitIdException"

	// ErrCodeInvalidPathException for service response error code
	// "InvalidPathException".
	//
	// The specified path is not valid.
	ErrCodeInvalidPathException = "InvalidPathException"

	// ErrCodeInvalidPullRequestEventTypeException for service response error code
	// "InvalidPullRequestEventTypeException".
	//
	// The pull request event type is not valid.
	ErrCodeInvalidPullRequestEventTypeException = "InvalidPullRequestEventTypeException"

	// ErrCodeInvalidPullRequestIdException for service response error code
	// "InvalidPullRequestIdException".
	//
	// The pull request ID is not valid. Make sure that you have provided the full
	// ID and that the pull request is in the specified repository, and then try
	// again.
	ErrCodeInvalidPullRequestIdException = "InvalidPullRequestIdException"

	// ErrCodeInvalidPullRequestStatusException for service response error code
	// "InvalidPullRequestStatusException".
	//
	// The pull request status is not valid. The only valid values are OPEN and
	// CLOSED.
	ErrCodeInvalidPullRequestStatusException = "InvalidPullRequestStatusException"

	// ErrCodeInvalidPullRequestStatusUpdateException for service response error code
	// "InvalidPullRequestStatusUpdateException".
	//
	// The pull request status update is not valid. The only valid update is from
	// OPEN to CLOSED.
	ErrCodeInvalidPullRequestStatusUpdateException = "InvalidPullRequestStatusUpdateException"

	// ErrCodeInvalidReactionUserArnException for service response error code
	// "InvalidReactionUserArnException".
	//
	// The Amazon Resource Name (ARN) of the user or identity is not valid.
	ErrCodeInvalidReactionUserArnException = "InvalidReactionUserArnException"

	// ErrCodeInvalidReactionValueException for service response error code
	// "InvalidReactionValueException".
	//
	// The value of the reaction is not valid. For more information, see the AWS
	// CodeCommit User Guide (https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html).
	ErrCodeInvalidReactionValueException = "InvalidReactionValueException"

	// ErrCodeInvalidReferenceNameException for service response error code
	// "InvalidReferenceNameException".
	//
	// The specified reference name format is not valid. Reference names must conform
	// to the Git references format (for example, refs/heads/master). For more information,
	// see Git Internals - Git References (https://git-scm.com/book/en/v2/Git-Internals-Git-References)
	// or consult your Git documentation.
	ErrCodeInvalidReferenceNameException = "InvalidReferenceNameException"

	// ErrCodeInvalidRelativeFileVersionEnumException for service response error code
	// "InvalidRelativeFileVersionEnumException".
	//
	// Either the enum is not in a valid format, or the specified file version enum
	// is not valid in respect to the current file version.
	ErrCodeInvalidRelativeFileVersionEnumException = "InvalidRelativeFileVersionEnumException"

	// ErrCodeInvalidReplacementContentException for service response error code
	// "InvalidReplacementContentException".
	//
	// Automerge was specified for resolving the conflict, but the replacement type
	// is not valid or content is missing.
	ErrCodeInvalidReplacementContentException = "InvalidReplacementContentException"

	// ErrCodeInvalidReplacementTypeException for service response error code
	// "InvalidReplacementTypeException".
	//
	// Automerge was specified for resolving the conflict, but the specified replacement
	// type is not valid.
	ErrCodeInvalidReplacementTypeException = "InvalidReplacementTypeException"

	// ErrCodeInvalidRepositoryDescriptionException for service response error code
	// "InvalidRepositoryDescriptionException".
	//
	// The specified repository description is not valid.
	ErrCodeInvalidRepositoryDescriptionException = "InvalidRepositoryDescriptionException"

	// ErrCodeInvalidRepositoryNameException for service response error code
	// "InvalidRepositoryNameException".
	//
	// A specified repository name is not valid.
	//
	// This exception occurs only when a specified repository name is not valid.
	// Other exceptions occur when a required repository parameter is missing, or
	// when a specified repository does not exist.
	ErrCodeInvalidRepositoryNameException = "InvalidRepositoryNameException"

	// ErrCodeInvalidRepositoryTriggerBranchNameException for service response error code
	// "InvalidRepositoryTriggerBranchNameException".
	//
	// One or more branch names specified for the trigger is not valid.
	ErrCodeInvalidRepositoryTriggerBranchNameException = "InvalidRepositoryTriggerBranchNameException"

	// ErrCodeInvalidRepositoryTriggerCustomDataException for service response error code
	// "InvalidRepositoryTriggerCustomDataException".
	//
	// The custom data provided for the trigger is not valid.
	ErrCodeInvalidRepositoryTriggerCustomDataException = "InvalidRepositoryTriggerCustomDataException"

	// ErrCodeInvalidRepositoryTriggerDestinationArnException for service response error code
	// "InvalidRepositoryTriggerDestinationArnException".
	//
	// The Amazon Resource Name (ARN) for the trigger is not valid for the specified
	// destination. The most common reason for this error is that the ARN does not
	// meet the requirements for the service type.
	ErrCodeInvalidRepositoryTriggerDestinationArnException = "InvalidRepositoryTriggerDestinationArnException"

	// ErrCodeInvalidRepositoryTriggerEventsException for service response error code
	// "InvalidRepositoryTriggerEventsException".
	//
	// One or more events specified for the trigger is not valid. Check to make
	// sure that all events specified match the requirements for allowed events.
	ErrCodeInvalidRepositoryTriggerEventsException = "InvalidRepositoryTriggerEventsException"

	// ErrCodeInvalidRepositoryTriggerNameException for service response error code
	// "InvalidRepositoryTriggerNameException".
	//
	// The name of the trigger is not valid.
	ErrCodeInvalidRepositoryTriggerNameException = "InvalidRepositoryTriggerNameException"

	// ErrCodeInvalidRepositoryTriggerRegionException for service response error code
	// "InvalidRepositoryTriggerRegionException".
	//
	// The AWS Region for the trigger target does not match the AWS Region for the
	// repository. Triggers must be created in the same Region as the target for
	// the trigger.
	ErrCodeInvalidRepositoryTriggerRegionException = "InvalidRepositoryTriggerRegionException"

	// ErrCodeInvalidResourceArnException for service response error code
	// "InvalidResourceArnException".
	//
	// The value for the resource ARN is not valid. For more information about resources
	// in AWS CodeCommit, see CodeCommit Resources and Operations (https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats)
	// in the AWS CodeCommit User Guide.
	ErrCodeInvalidResourceArnException = "InvalidResourceArnException"

	// ErrCodeInvalidRevisionIdException for service response error code
	// "InvalidRevisionIdException".
	//
	// The revision ID is not valid. Use GetPullRequest to determine the value.
	ErrCodeInvalidRevisionIdException = "InvalidRevisionIdException"

	// ErrCodeInvalidRuleContentSha256Exception for service response error code
	// "InvalidRuleContentSha256Exception".
	//
	// The SHA-256 hash signature for the rule content is not valid.
	ErrCodeInvalidRuleContentSha256Exception = "InvalidRuleContentSha256Exception"

	// ErrCodeInvalidSortByException for service response error code
	// "InvalidSortByException".
	//
	// The specified sort by value is not valid.
	ErrCodeInvalidSortByException = "InvalidSortByException"

	// ErrCodeInvalidSourceCommitSpecifierException for service response error code
	// "InvalidSourceCommitSpecifierException".
	//
	// The source commit specifier is not valid. You must provide a valid branch
	// name, tag, or full commit ID.
	ErrCodeInvalidSourceCommitSpecifierException = "InvalidSourceCommitSpecifierException"

	// ErrCodeInvalidSystemTagUsageException for service response error code
	// "InvalidSystemTagUsageException".
	//
	// The specified tag is not valid. Key names cannot be prefixed with aws:.
	ErrCodeInvalidSystemTagUsageException = "InvalidSystemTagUsageException"

	// ErrCodeInvalidTagKeysListException for service response error code
	// "InvalidTagKeysListException".
	//
	// The list of tags is not valid.
	ErrCodeInvalidTagKeysListException = "InvalidTagKeysListException"

	// ErrCodeInvalidTagsMapException for service response error code
	// "InvalidTagsMapException".
	//
	// The map of tags is not valid.
	ErrCodeInvalidTagsMapException = "InvalidTagsMapException"

	// ErrCodeInvalidTargetBranchException for service response error code
	// "InvalidTargetBranchException".
	//
	// The specified target branch is not valid.
	ErrCodeInvalidTargetBranchException = "InvalidTargetBranchException"

	// ErrCodeInvalidTargetException for service response error code
	// "InvalidTargetException".
	//
	// The target for the pull request is not valid. A target must contain the full
	// values for the repository name, source branch, and destination branch for
	// the pull request.
	ErrCodeInvalidTargetException = "InvalidTargetException"

	// ErrCodeInvalidTargetsException for service response error code
	// "InvalidTargetsException".
	//
	// The targets for the pull request is not valid or not in a valid format. Targets
	// are a list of target objects. Each target object must contain the full values
	// for the repository name, source branch, and destination branch for a pull
	// request.
	ErrCodeInvalidTargetsException = "InvalidTargetsException"

	// ErrCodeInvalidTitleException for service response error code
	// "InvalidTitleException".
	//
	// The title of the pull request is not valid. Pull request titles cannot exceed
	// 100 characters in length.
	ErrCodeInvalidTitleException = "InvalidTitleException"

	// ErrCodeManualMergeRequiredException for service response error code
	// "ManualMergeRequiredException".
	//
	// The pull request cannot be merged automatically into the destination branch.
	// You must manually merge the branches and resolve any conflicts.
	ErrCodeManualMergeRequiredException = "ManualMergeRequiredException"

	// ErrCodeMaximumBranchesExceededException for service response error code
	// "MaximumBranchesExceededException".
	//
	// The number of branches for the trigger was exceeded.
	ErrCodeMaximumBranchesExceededException = "MaximumBranchesExceededException"

	// ErrCodeMaximumConflictResolutionEntriesExceededException for service response error code
	// "MaximumConflictResolutionEntriesExceededException".
	//
	// The number of allowed conflict resolution entries was exceeded.
	ErrCodeMaximumConflictResolutionEntriesExceededException = "MaximumConflictResolutionEntriesExceededException"

	// ErrCodeMaximumFileContentToLoadExceededException for service response error code
	// "MaximumFileContentToLoadExceededException".
	//
	// The number of files to load exceeds the allowed limit.
	ErrCodeMaximumFileContentToLoadExceededException = "MaximumFileContentToLoadExceededException"

	// ErrCodeMaximumFileEntriesExceededException for service response error code
	// "MaximumFileEntriesExceededException".
	//
	// The number of specified files to change as part of this commit exceeds the
	// maximum number of files that can be changed in a single commit. Consider
	// using a Git client for these changes.
	ErrCodeMaximumFileEntriesExceededException = "MaximumFileEntriesExceededException"

	// ErrCodeMaximumItemsToCompareExceededException for service response error code
	// "MaximumItemsToCompareExceededException".
	//
	// The number of items to compare between the source or destination branches
	// and the merge base has exceeded the maximum allowed.
	ErrCodeMaximumItemsToCompareExceededException = "MaximumItemsToCompareExceededException"

	// ErrCodeMaximumNumberOfApprovalsExceededException for service response error code
	// "MaximumNumberOfApprovalsExceededException".
	//
	// The number of approvals required for the approval rule exceeds the maximum
	// number allowed.
	ErrCodeMaximumNumberOfApprovalsExceededException = "MaximumNumberOfApprovalsExceededException"

	// ErrCodeMaximumOpenPullRequestsExceededException for service response error code
	// "MaximumOpenPullRequestsExceededException".
	//
	// You cannot create the pull request because the repository has too many open
	// pull requests. The maximum number of open pull requests for a repository
	// is 1,000. Close one or more open pull requests, and then try again.
	ErrCodeMaximumOpenPullRequestsExceededException = "MaximumOpenPullRequestsExceededException"

	// ErrCodeMaximumRepositoryNamesExceededException for service response error code
	// "MaximumRepositoryNamesExceededException".
	//
	// The maximum number of allowed repository names was exceeded. Currently, this
	// number is 100.
	ErrCodeMaximumRepositoryNamesExceededException = "MaximumRepositoryNamesExceededException"

	// ErrCodeMaximumRepositoryTriggersExceededException for service response error code
	// "MaximumRepositoryTriggersExceededException".
	//
	// The number of triggers allowed for the repository was exceeded.
	ErrCodeMaximumRepositoryTriggersExceededException = "MaximumRepositoryTriggersExceededException"

	// ErrCodeMaximumRuleTemplatesAssociatedWithRepositoryException for service response error code
	// "MaximumRuleTemplatesAssociatedWithRepositoryException".
	//
	// The maximum number of approval rule templates for a repository has been exceeded.
	// You cannot associate more than 25 approval rule templates with a repository.
	ErrCodeMaximumRuleTemplatesAssociatedWithRepositoryException = "MaximumRuleTemplatesAssociatedWithRepositoryException"

	// ErrCodeMergeOptionRequiredException for service response error code
	// "MergeOptionRequiredException".
	//
	// A merge option or stategy is required, and none was provided.
	ErrCodeMergeOptionRequiredException = "MergeOptionRequiredException"

	// ErrCodeMultipleConflictResolutionEntriesException for service response error code
	// "MultipleConflictResolutionEntriesException".
	//
	// More than one conflict resolution entries exists for the conflict. A conflict
	// can have only one conflict resolution entry.
	ErrCodeMultipleConflictResolutionEntriesException = "MultipleConflictResolutionEntriesException"

	// ErrCodeMultipleRepositoriesInPullRequestException for service response error code
	// "MultipleRepositoriesInPullRequestException".
	//
	// You cannot include more than one repository in a pull request. Make sure
	// you have specified only one repository name in your request, and then try
	// again.
	ErrCodeMultipleRepositoriesInPullRequestException = "MultipleRepositoriesInPullRequestException"

	// ErrCodeNameLengthExceededException for service response error code
	// "NameLengthExceededException".
	//
	// The user name is not valid because it has exceeded the character limit for
	// author names.
	ErrCodeNameLengthExceededException = "NameLengthExceededException"

	// ErrCodeNoChangeException for service response error code
	// "NoChangeException".
	//
	// The commit cannot be created because no changes will be made to the repository
	// as a result of this commit. A commit must contain at least one change.
	ErrCodeNoChangeException = "NoChangeException"

	// ErrCodeNumberOfRuleTemplatesExceededException for service response error code
	// "NumberOfRuleTemplatesExceededException".
	//
	// The maximum number of approval rule templates has been exceeded for this
	// AWS Region.
	ErrCodeNumberOfRuleTemplatesExceededException = "NumberOfRuleTemplatesExceededException"

	// ErrCodeNumberOfRulesExceededException for service response error code
	// "NumberOfRulesExceededException".
	//
	// The approval rule cannot be added. The pull request has the maximum number
	// of approval rules associated with it.
	ErrCodeNumberOfRulesExceededException = "NumberOfRulesExceededException"

	// ErrCodeOverrideAlreadySetException for service response error code
	// "OverrideAlreadySetException".
	//
	// The pull request has already had its approval rules set to override.
	ErrCodeOverrideAlreadySetException = "OverrideAlreadySetException"

	// ErrCodeOverrideStatusRequiredException for service response error code
	// "OverrideStatusRequiredException".
	//
	// An override status is required, but no value was provided. Valid values include
	// OVERRIDE and REVOKE.
	ErrCodeOverrideStatusRequiredException = "OverrideStatusRequiredException"

	// ErrCodeParentCommitDoesNotExistException for service response error code
	// "ParentCommitDoesNotExistException".
	//
	// The parent commit ID is not valid because it does not exist. The specified
	// parent commit ID does not exist in the specified branch of the repository.
	ErrCodeParentCommitDoesNotExistException = "ParentCommitDoesNotExistException"

	// ErrCodeParentCommitIdOutdatedException for service response error code
	// "ParentCommitIdOutdatedException".
	//
	// The file could not be added because the provided parent commit ID is not
	// the current tip of the specified branch. To view the full commit ID of the
	// current head of the branch, use GetBranch.
	ErrCodeParentCommitIdOutdatedException = "ParentCommitIdOutdatedException"

	// ErrCodeParentCommitIdRequiredException for service response error code
	// "ParentCommitIdRequiredException".
	//
	// A parent commit ID is required. To view the full commit ID of a branch in
	// a repository, use GetBranch or a Git command (for example, git pull or git
	// log).
	ErrCodeParentCommitIdRequiredException = "ParentCommitIdRequiredException"

	// ErrCodePathDoesNotExistException for service response error code
	// "PathDoesNotExistException".
	//
	// The specified path does not exist.
	ErrCodePathDoesNotExistException = "PathDoesNotExistException"

	// ErrCodePathRequiredException for service response error code
	// "PathRequiredException".
	//
	// The folderPath for a location cannot be null.
	ErrCodePathRequiredException = "PathRequiredException"

	// ErrCodePullRequestAlreadyClosedException for service response error code
	// "PullRequestAlreadyClosedException".
	//
	// The pull request status cannot be updated because it is already closed.
	ErrCodePullRequestAlreadyClosedException = "PullRequestAlreadyClosedException"

	// ErrCodePullRequestApprovalRulesNotSatisfiedException for service response error code
	// "PullRequestApprovalRulesNotSatisfiedException".
	//
	// The pull request cannot be merged because one or more approval rules applied
	// to the pull request have conditions that have not been met.
	ErrCodePullRequestApprovalRulesNotSatisfiedException = "PullRequestApprovalRulesNotSatisfiedException"

	// ErrCodePullRequestCannotBeApprovedByAuthorException for service response error code
	// "PullRequestCannotBeApprovedByAuthorException".
	//
	// The approval cannot be applied because the user approving the pull request
	// matches the user who created the pull request. You cannot approve a pull
	// request that you created.
	ErrCodePullRequestCannotBeApprovedByAuthorException = "PullRequestCannotBeApprovedByAuthorException"

	// ErrCodePullRequestDoesNotExistException for service response error code
	// "PullRequestDoesNotExistException".
	//
	// The pull request ID could not be found. Make sure that you have specified
	// the correct repository name and pull request ID, and then try again.
	ErrCodePullRequestDoesNotExistException = "PullRequestDoesNotExistException"

	// ErrCodePullRequestIdRequiredException for service response error code
	// "PullRequestIdRequiredException".
	//
	// A pull request ID is required, but none was provided.
	ErrCodePullRequestIdRequiredException = "PullRequestIdRequiredException"

	// ErrCodePullRequestStatusRequiredException for service response error code
	// "PullRequestStatusRequiredException".
	//
	// A pull request status is required, but none was provided.
	ErrCodePullRequestStatusRequiredException = "PullRequestStatusRequiredException"

	// ErrCodePutFileEntryConflictException for service response error code
	// "PutFileEntryConflictException".
	//
	// The commit cannot be created because one or more files specified in the commit
	// reference both a file and a folder.
	ErrCodePutFileEntryConflictException = "PutFileEntryConflictException"

	// ErrCodeReactionLimitExceededException for service response error code
	// "ReactionLimitExceededException".
	//
	// The number of reactions has been exceeded. Reactions are limited to one reaction
	// per user for each individual comment ID.
	ErrCodeReactionLimitExceededException = "ReactionLimitExceededException"

	// ErrCodeReactionValueRequiredException for service response error code
	// "ReactionValueRequiredException".
	//
	// A reaction value is required.
	ErrCodeReactionValueRequiredException = "ReactionValueRequiredException"

	// ErrCodeReferenceDoesNotExistException for service response error code
	// "ReferenceDoesNotExistException".
	//
	// The specified reference does not exist. You must provide a full commit ID.
	ErrCodeReferenceDoesNotExistException = "ReferenceDoesNotExistException"

	// ErrCodeReferenceNameRequiredException for service response error code
	// "ReferenceNameRequiredException".
	//
	// A reference name is required, but none was provided.
	ErrCodeReferenceNameRequiredException = "ReferenceNameRequiredException"

	// ErrCodeReferenceTypeNotSupportedException for service response error code
	// "ReferenceTypeNotSupportedException".
	//
	// The specified reference is not a supported type.
	ErrCodeReferenceTypeNotSupportedException = "ReferenceTypeNotSupportedException"

	// ErrCodeReplacementContentRequiredException for service response error code
	// "ReplacementContentRequiredException".
	//
	// USE_NEW_CONTENT was specified, but no replacement content has been provided.
	ErrCodeReplacementContentRequiredException = "ReplacementContentRequiredException"

	// ErrCodeReplacementTypeRequiredException for service response error code
	// "ReplacementTypeRequiredException".
	//
	// A replacement type is required.
	ErrCodeReplacementTypeRequiredException = "ReplacementTypeRequiredException"

	// ErrCodeRepositoryDoesNotExistException for service response error code
	// "RepositoryDoesNotExistException".
	//
	// The specified repository does not exist.
	ErrCodeRepositoryDoesNotExistException = "RepositoryDoesNotExistException"

	// ErrCodeRepositoryLimitExceededException for service response error code
	// "RepositoryLimitExceededException".
	//
	// A repository resource limit was exceeded.
	ErrCodeRepositoryLimitExceededException = "RepositoryLimitExceededException"

	// ErrCodeRepositoryNameExistsException for service response error code
	// "RepositoryNameExistsException".
	//
	// The specified repository name already exists.
	ErrCodeRepositoryNameExistsException = "RepositoryNameExistsException"

	// ErrCodeRepositoryNameRequiredException for service response error code
	// "RepositoryNameRequiredException".
	//
	// A repository name is required, but was not specified.
	ErrCodeRepositoryNameRequiredException = "RepositoryNameRequiredException"

	// ErrCodeRepositoryNamesRequiredException for service response error code
	// "RepositoryNamesRequiredException".
	//
	// At least one repository name object is required, but was not specified.
	ErrCodeRepositoryNamesRequiredException = "RepositoryNamesRequiredException"

	// ErrCodeRepositoryNotAssociatedWithPullRequestException for service response error code
	// "RepositoryNotAssociatedWithPullRequestException".
	//
	// The repository does not contain any pull requests with that pull request
	// ID. Use GetPullRequest to verify the correct repository name for the pull
	// request ID.
	ErrCodeRepositoryNotAssociatedWithPullRequestException = "RepositoryNotAssociatedWithPullRequestException"

	// ErrCodeRepositoryTriggerBranchNameListRequiredException for service response error code
	// "RepositoryTriggerBranchNameListRequiredException".
	//
	// At least one branch name is required, but was not specified in the trigger
	// configuration.
	ErrCodeRepositoryTriggerBranchNameListRequiredException = "RepositoryTriggerBranchNameListRequiredException"

	// ErrCodeRepositoryTriggerDestinationArnRequiredException for service response error code
	// "RepositoryTriggerDestinationArnRequiredException".
	//
	// A destination ARN for the target service for the trigger is required, but
	// was not specified.
	ErrCodeRepositoryTriggerDestinationArnRequiredException = "RepositoryTriggerDestinationArnRequiredException"

	// ErrCodeRepositoryTriggerEventsListRequiredException for service response error code
	// "RepositoryTriggerEventsListRequiredException".
	//
	// At least one event for the trigger is required, but was not specified.
	ErrCodeRepositoryTriggerEventsListRequiredException = "RepositoryTriggerEventsListRequiredException"

	// ErrCodeRepositoryTriggerNameRequiredException for service response error code
	// "RepositoryTriggerNameRequiredException".
	//
	// A name for the trigger is required, but was not specified.
	ErrCodeRepositoryTriggerNameRequiredException = "RepositoryTriggerNameRequiredException"

	// ErrCodeRepositoryTriggersListRequiredException for service response error code
	// "RepositoryTriggersListRequiredException".
	//
	// The list of triggers for the repository is required, but was not specified.
	ErrCodeRepositoryTriggersListRequiredException = "RepositoryTriggersListRequiredException"

	// ErrCodeResourceArnRequiredException for service response error code
	// "ResourceArnRequiredException".
	//
	// A valid Amazon Resource Name (ARN) for an AWS CodeCommit resource is required.
	// For a list of valid resources in AWS CodeCommit, see CodeCommit Resources
	// and Operations (https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats)
	// in the AWS CodeCommit User Guide.
	ErrCodeResourceArnRequiredException = "ResourceArnRequiredException"

	// ErrCodeRestrictedSourceFileException for service response error code
	// "RestrictedSourceFileException".
	//
	// The commit cannot be created because one of the changes specifies copying
	// or moving a .gitkeep file.
	ErrCodeRestrictedSourceFileException = "RestrictedSourceFileException"

	// ErrCodeRevisionIdRequiredException for service response error code
	// "RevisionIdRequiredException".
	//
	// A revision ID is required, but was not provided.
	ErrCodeRevisionIdRequiredException = "RevisionIdRequiredException"

	// ErrCodeRevisionNotCurrentException for service response error code
	// "RevisionNotCurrentException".
	//
	// The revision ID provided in the request does not match the current revision
	// ID. Use GetPullRequest to retrieve the current revision ID.
	ErrCodeRevisionNotCurrentException = "RevisionNotCurrentException"

	// ErrCodeSameFileContentException for service response error code
	// "SameFileContentException".
	//
	// The file was not added or updated because the content of the file is exactly
	// the same as the content of that file in the repository and branch that you
	// specified.
	ErrCodeSameFileContentException = "SameFileContentException"

	// ErrCodeSamePathRequestException for service response error code
	// "SamePathRequestException".
	//
	// The commit cannot be created because one or more changes in this commit duplicate
	// actions in the same file path. For example, you cannot make the same delete
	// request to the same file in the same file path twice, or make a delete request
	// and a move request to the same file as part of the same commit.
	ErrCodeSamePathRequestException = "SamePathRequestException"

	// ErrCodeSourceAndDestinationAreSameException for service response error code
	// "SourceAndDestinationAreSameException".
	//
	// The source branch and destination branch for the pull request are the same.
	// You must specify different branches for the source and destination.
	ErrCodeSourceAndDestinationAreSameException = "SourceAndDestinationAreSameException"

	// ErrCodeSourceFileOrContentRequiredException for service response error code
	// "SourceFileOrContentRequiredException".
	//
	// The commit cannot be created because no source files or file content have
	// been specified for the commit.
	ErrCodeSourceFileOrContentRequiredException = "SourceFileOrContentRequiredException"

	// ErrCodeTagKeysListRequiredException for service response error code
	// "TagKeysListRequiredException".
	//
	// A list of tag keys is required. The list cannot be empty or null.
	ErrCodeTagKeysListRequiredException = "TagKeysListRequiredException"

	// ErrCodeTagPolicyException for service response error code
	// "TagPolicyException".
	//
	// The tag policy is not valid.
	ErrCodeTagPolicyException = "TagPolicyException"

	// ErrCodeTagsMapRequiredException for service response error code
	// "TagsMapRequiredException".
	//
	// A map of tags is required.
	ErrCodeTagsMapRequiredException = "TagsMapRequiredException"

	// ErrCodeTargetRequiredException for service response error code
	// "TargetRequiredException".
	//
	// A pull request target is required. It cannot be empty or null. A pull request
	// target must contain the full values for the repository name, source branch,
	// and destination branch for the pull request.
	ErrCodeTargetRequiredException = "TargetRequiredException"

	// ErrCodeTargetsRequiredException for service response error code
	// "TargetsRequiredException".
	//
	// An array of target objects is required. It cannot be empty or null.
	ErrCodeTargetsRequiredException = "TargetsRequiredException"

	// ErrCodeTipOfSourceReferenceIsDifferentException for service response error code
	// "TipOfSourceReferenceIsDifferentException".
	//
	// The tip of the source branch in the destination repository does not match
	// the tip of the source branch specified in your request. The pull request
	// might have been updated. Make sure that you have the latest changes.
	ErrCodeTipOfSourceReferenceIsDifferentException = "TipOfSourceReferenceIsDifferentException"

	// ErrCodeTipsDivergenceExceededException for service response error code
	// "TipsDivergenceExceededException".
	//
	// The divergence between the tips of the provided commit specifiers is too
	// great to determine whether there might be any merge conflicts. Locally compare
	// the specifiers using git diff or a diff tool.
	ErrCodeTipsDivergenceExceededException = "TipsDivergenceExceededException"

	// ErrCodeTitleRequiredException for service response error code
	// "TitleRequiredException".
	//
	// A pull request title is required. It cannot be empty or null.
	ErrCodeTitleRequiredException = "TitleRequiredException"

	// ErrCodeTooManyTagsException for service response error code
	// "TooManyTagsException".
	//
	// The maximum number of tags for an AWS CodeCommit resource has been exceeded.
	ErrCodeTooManyTagsException = "TooManyTagsException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"ActorDoesNotExistException":                            newErrorActorDoesNotExistException,
	"ApprovalRuleContentRequiredException":                  newErrorApprovalRuleContentRequiredException,
	"ApprovalRuleDoesNotExistException":                     newErrorApprovalRuleDoesNotExistException,
	"ApprovalRuleNameAlreadyExistsException":                newErrorApprovalRuleNameAlreadyExistsException,
	"ApprovalRuleNameRequiredException":                     newErrorApprovalRuleNameRequiredException,
	"ApprovalRuleTemplateContentRequiredException":          newErrorApprovalRuleTemplateContentRequiredException,
	"ApprovalRuleTemplateDoesNotExistException":             newErrorApprovalRuleTemplateDoesNotExistException,
	"ApprovalRuleTemplateInUseException":                    newErrorApprovalRuleTemplateInUseException,
	"ApprovalRuleTemplateNameAlreadyExistsException":        newErrorApprovalRuleTemplateNameAlreadyExistsException,
	"ApprovalRuleTemplateNameRequiredException":             newErrorApprovalRuleTemplateNameRequiredException,
	"ApprovalStateRequiredException":                        newErrorApprovalStateRequiredException,
	"AuthorDoesNotExistException":                           newErrorAuthorDoesNotExistException,
	"BeforeCommitIdAndAfterCommitIdAreSameException":        newErrorBeforeCommitIdAndAfterCommitIdAreSameException,
	"BlobIdDoesNotExistException":                           newErrorBlobIdDoesNotExistException,
	"BlobIdRequiredException":                               newErrorBlobIdRequiredException,
	"BranchDoesNotExistException":                           newErrorBranchDoesNotExistException,
	"BranchNameExistsException":                             newErrorBranchNameExistsException,
	"BranchNameIsTagNameException":                          newErrorBranchNameIsTagNameException,
	"BranchNameRequiredException":                           newErrorBranchNameRequiredException,
	"CannotDeleteApprovalRuleFromTemplateException":         newErrorCannotDeleteApprovalRuleFromTemplateException,
	"CannotModifyApprovalRuleFromTemplateException":         newErrorCannotModifyApprovalRuleFromTemplateException,
	"ClientRequestTokenRequiredException":                   newErrorClientRequestTokenRequiredException,
	"CommentContentRequiredException":                       newErrorCommentContentRequiredException,
	"CommentContentSizeLimitExceededException":              newErrorCommentContentSizeLimitExceededException,
	"CommentDeletedException":                               newErrorCommentDeletedException,
	"CommentDoesNotExistException":                          newErrorCommentDoesNotExistException,
	"CommentIdRequiredException":                            newErrorCommentIdRequiredException,
	"CommentNotCreatedByCallerException":                    newErrorCommentNotCreatedByCallerException,
	"CommitDoesNotExistException":                           newErrorCommitDoesNotExistException,
	"CommitIdDoesNotExistException":                         newErrorCommitIdDoesNotExistException,
	"CommitIdRequiredException":                             newErrorCommitIdRequiredException,
	"CommitIdsLimitExceededException":                       newErrorCommitIdsLimitExceededException,
	"CommitIdsListRequiredException":                        newErrorCommitIdsListRequiredException,
	"CommitMessageLengthExceededException":                  newErrorCommitMessageLengthExceededException,
	"CommitRequiredException":                               newErrorCommitRequiredException,
	"ConcurrentReferenceUpdateException":                    newErrorConcurrentReferenceUpdateException,
	"DefaultBranchCannotBeDeletedException":                 newErrorDefaultBranchCannotBeDeletedException,
	"DirectoryNameConflictsWithFileNameException":           newErrorDirectoryNameConflictsWithFileNameException,
	"EncryptionIntegrityChecksFailedException":              newErrorEncryptionIntegrityChecksFailedException,
	"EncryptionKeyAccessDeniedException":                    newErrorEncryptionKeyAccessDeniedException,
	"EncryptionKeyDisabledException":                        newErrorEncryptionKeyDisabledException,
	"EncryptionKeyNotFoundException":                        newErrorEncryptionKeyNotFoundException,
	"EncryptionKeyUnavailableException":                     newErrorEncryptionKeyUnavailableException,
	"FileContentAndSourceFileSpecifiedException":            newErrorFileContentAndSourceFileSpecifiedException,
	"FileContentRequiredException":                          newErrorFileContentRequiredException,
	"FileContentSizeLimitExceededException":                 newErrorFileContentSizeLimitExceededException,
	"FileDoesNotExistException":                             newErrorFileDoesNotExistException,
	"FileEntryRequiredException":                            newErrorFileEntryRequiredException,
	"FileModeRequiredException":                             newErrorFileModeRequiredException,
	"FileNameConflictsWithDirectoryNameException":           newErrorFileNameConflictsWithDirectoryNameException,
	"FilePathConflictsWithSubmodulePathException":           newErrorFilePathConflictsWithSubmodulePathException,
	"FileTooLargeException":                                 newErrorFileTooLargeException,
	"FolderContentSizeLimitExceededException":               newErrorFolderContentSizeLimitExceededException,
	"FolderDoesNotExistException":                           newErrorFolderDoesNotExistException,
	"IdempotencyParameterMismatchException":                 newErrorIdempotencyParameterMismatchException,
	"InvalidActorArnException":                              newErrorInvalidActorArnException,
	"InvalidApprovalRuleContentException":                   newErrorInvalidApprovalRuleContentException,
	"InvalidApprovalRuleNameException":                      newErrorInvalidApprovalRuleNameException,
	"InvalidApprovalRuleTemplateContentException":           newErrorInvalidApprovalRuleTemplateContentException,
	"InvalidApprovalRuleTemplateDescriptionException":       newErrorInvalidApprovalRuleTemplateDescriptionException,
	"InvalidApprovalRuleTemplateNameException":              newErrorInvalidApprovalRuleTemplateNameException,
	"InvalidApprovalStateException":                         newErrorInvalidApprovalStateException,
	"InvalidAuthorArnException":                             newErrorInvalidAuthorArnException,
	"InvalidBlobIdException":                                newErrorInvalidBlobIdException,
	"InvalidBranchNameException":                            newErrorInvalidBranchNameException,
	"InvalidClientRequestTokenException":                    newErrorInvalidClientRequestTokenException,
	"InvalidCommentIdException":                             newErrorInvalidCommentIdException,
	"InvalidCommitException":                                newErrorInvalidCommitException,
	"InvalidCommitIdException":                              newErrorInvalidCommitIdException,
	"InvalidConflictDetailLevelException":                   newErrorInvalidConflictDetailLevelException,
	"InvalidConflictResolutionException":                    newErrorInvalidConflictResolutionException,
	"InvalidConflictResolutionStrategyException":            newErrorInvalidConflictResolutionStrategyException,
	"InvalidContinuationTokenException":                     newErrorInvalidContinuationTokenException,
	"InvalidDeletionParameterException":                     newErrorInvalidDeletionParameterException,
	"InvalidDescriptionException":                           newErrorInvalidDescriptionException,
	"InvalidDestinationCommitSpecifierException":            newErrorInvalidDestinationCommitSpecifierException,
	"InvalidEmailException":                                 newErrorInvalidEmailException,
	"InvalidFileLocationException":                          newErrorInvalidFileLocationException,
	"InvalidFileModeException":                              newErrorInvalidFileModeException,
	"InvalidFilePositionException":                          newErrorInvalidFilePositionException,
	"InvalidMaxConflictFilesException":                      newErrorInvalidMaxConflictFilesException,
	"InvalidMaxMergeHunksException":                         newErrorInvalidMaxMergeHunksException,
	"InvalidMaxResultsException":                            newErrorInvalidMaxResultsException,
	"InvalidMergeOptionException":                           newErrorInvalidMergeOptionException,
	"InvalidOrderException":                                 newErrorInvalidOrderException,
	"InvalidOverrideStatusException":                        newErrorInvalidOverrideStatusException,
	"InvalidParentCommitIdException":                        newErrorInvalidParentCommitIdException,
	"InvalidPathException":                                  newErrorInvalidPathException,
	"InvalidPullRequestEventTypeException":                  newErrorInvalidPullRequestEventTypeException,
	"InvalidPullRequestIdException":                         newErrorInvalidPullRequestIdException,
	"InvalidPullRequestStatusException":                     newErrorInvalidPullRequestStatusException,
	"InvalidPullRequestStatusUpdateException":               newErrorInvalidPullRequestStatusUpdateException,
	"InvalidReactionUserArnException":                       newErrorInvalidReactionUserArnException,
	"InvalidReactionValueException":                         newErrorInvalidReactionValueException,
	"InvalidReferenceNameException":                         newErrorInvalidReferenceNameException,
	"InvalidRelativeFileVersionEnumException":               newErrorInvalidRelativeFileVersionEnumException,
	"InvalidReplacementContentException":                    newErrorInvalidReplacementContentException,
	"InvalidReplacementTypeException":                       newErrorInvalidReplacementTypeException,
	"InvalidRepositoryDescriptionException":                 newErrorInvalidRepositoryDescriptionException,
	"InvalidRepositoryNameException":                        newErrorInvalidRepositoryNameException,
	"InvalidRepositoryTriggerBranchNameException":           newErrorInvalidRepositoryTriggerBranchNameException,
	"InvalidRepositoryTriggerCustomDataException":           newErrorInvalidRepositoryTriggerCustomDataException,
	"InvalidRepositoryTriggerDestinationArnException":       newErrorInvalidRepositoryTriggerDestinationArnException,
	"InvalidRepositoryTriggerEventsException":               newErrorInvalidRepositoryTriggerEventsException,
	"InvalidRepositoryTriggerNameException":                 newErrorInvalidRepositoryTriggerNameException,
	"InvalidRepositoryTriggerRegionException":               newErrorInvalidRepositoryTriggerRegionException,
	"InvalidResourceArnException":                           newErrorInvalidResourceArnException,
	"InvalidRevisionIdException":                            newErrorInvalidRevisionIdException,
	"InvalidRuleContentSha256Exception":                     newErrorInvalidRuleContentSha256Exception,
	"InvalidSortByException":                                newErrorInvalidSortByException,
	"InvalidSourceCommitSpecifierException":                 newErrorInvalidSourceCommitSpecifierException,
	"InvalidSystemTagUsageException":                        newErrorInvalidSystemTagUsageException,
	"InvalidTagKeysListException":                           newErrorInvalidTagKeysListException,
	"InvalidTagsMapException":                               newErrorInvalidTagsMapException,
	"InvalidTargetBranchException":                          newErrorInvalidTargetBranchException,
	"InvalidTargetException":                                newErrorInvalidTargetException,
	"InvalidTargetsException":                               newErrorInvalidTargetsException,
	"InvalidTitleException":                                 newErrorInvalidTitleException,
	"ManualMergeRequiredException":                          newErrorManualMergeRequiredException,
	"MaximumBranchesExceededException":                      newErrorMaximumBranchesExceededException,
	"MaximumConflictResolutionEntriesExceededException":     newErrorMaximumConflictResolutionEntriesExceededException,
	"MaximumFileContentToLoadExceededException":             newErrorMaximumFileContentToLoadExceededException,
	"MaximumFileEntriesExceededException":                   newErrorMaximumFileEntriesExceededException,
	"MaximumItemsToCompareExceededException":                newErrorMaximumItemsToCompareExceededException,
	"MaximumNumberOfApprovalsExceededException":             newErrorMaximumNumberOfApprovalsExceededException,
	"MaximumOpenPullRequestsExceededException":              newErrorMaximumOpenPullRequestsExceededException,
	"MaximumRepositoryNamesExceededException":               newErrorMaximumRepositoryNamesExceededException,
	"MaximumRepositoryTriggersExceededException":            newErrorMaximumRepositoryTriggersExceededException,
	"MaximumRuleTemplatesAssociatedWithRepositoryException": newErrorMaximumRuleTemplatesAssociatedWithRepositoryException,
	"MergeOptionRequiredException":                          newErrorMergeOptionRequiredException,
	"MultipleConflictResolutionEntriesException":            newErrorMultipleConflictResolutionEntriesException,
	"MultipleRepositoriesInPullRequestException":            newErrorMultipleRepositoriesInPullRequestException,
	"NameLengthExceededException":                           newErrorNameLengthExceededException,
	"NoChangeException":                                     newErrorNoChangeException,
	"NumberOfRuleTemplatesExceededException":                newErrorNumberOfRuleTemplatesExceededException,
	"NumberOfRulesExceededException":                        newErrorNumberOfRulesExceededException,
	"OverrideAlreadySetException":                           newErrorOverrideAlreadySetException,
	"OverrideStatusRequiredException":                       newErrorOverrideStatusRequiredException,
	"ParentCommitDoesNotExistException":                     newErrorParentCommitDoesNotExistException,
	"ParentCommitIdOutdatedException":                       newErrorParentCommitIdOutdatedException,
	"ParentCommitIdRequiredException":                       newErrorParentCommitIdRequiredException,
	"PathDoesNotExistException":                             newErrorPathDoesNotExistException,
	"PathRequiredException":                                 newErrorPathRequiredException,
	"PullRequestAlreadyClosedException":                     newErrorPullRequestAlreadyClosedException,
	"PullRequestApprovalRulesNotSatisfiedException":         newErrorPullRequestApprovalRulesNotSatisfiedException,
	"PullRequestCannotBeApprovedByAuthorException":          newErrorPullRequestCannotBeApprovedByAuthorException,
	"PullRequestDoesNotExistException":                      newErrorPullRequestDoesNotExistException,
	"PullRequestIdRequiredException":                        newErrorPullRequestIdRequiredException,
	"PullRequestStatusRequiredException":                    newErrorPullRequestStatusRequiredException,
	"PutFileEntryConflictException":                         newErrorPutFileEntryConflictException,
	"ReactionLimitExceededException":                        newErrorReactionLimitExceededException,
	"ReactionValueRequiredException":                        newErrorReactionValueRequiredException,
	"ReferenceDoesNotExistException":                        newErrorReferenceDoesNotExistException,
	"ReferenceNameRequiredException":                        newErrorReferenceNameRequiredException,
	"ReferenceTypeNotSupportedException":                    newErrorReferenceTypeNotSupportedException,
	"ReplacementContentRequiredException":                   newErrorReplacementContentRequiredException,
	"ReplacementTypeRequiredException":                      newErrorReplacementTypeRequiredException,
	"RepositoryDoesNotExistException":                       newErrorRepositoryDoesNotExistException,
	"RepositoryLimitExceededException":                      newErrorRepositoryLimitExceededException,
	"RepositoryNameExistsException":                         newErrorRepositoryNameExistsException,
	"RepositoryNameRequiredException":                       newErrorRepositoryNameRequiredException,
	"RepositoryNamesRequiredException":                      newErrorRepositoryNamesRequiredException,
	"RepositoryNotAssociatedWithPullRequestException":       newErrorRepositoryNotAssociatedWithPullRequestException,
	"RepositoryTriggerBranchNameListRequiredException":      newErrorRepositoryTriggerBranchNameListRequiredException,
	"RepositoryTriggerDestinationArnRequiredException":      newErrorRepositoryTriggerDestinationArnRequiredException,
	"RepositoryTriggerEventsListRequiredException":          newErrorRepositoryTriggerEventsListRequiredException,
	"RepositoryTriggerNameRequiredException":                newErrorRepositoryTriggerNameRequiredException,
	"RepositoryTriggersListRequiredException":               newErrorRepositoryTriggersListRequiredException,
	"ResourceArnRequiredException":                          newErrorResourceArnRequiredException,
	"RestrictedSourceFileException":                         newErrorRestrictedSourceFileException,
	"RevisionIdRequiredException":                           newErrorRevisionIdRequiredException,
	"RevisionNotCurrentException":                           newErrorRevisionNotCurrentException,
	"SameFileContentException":                              newErrorSameFileContentException,
	"SamePathRequestException":                              newErrorSamePathRequestException,
	"SourceAndDestinationAreSameException":                  newErrorSourceAndDestinationAreSameException,
	"SourceFileOrContentRequiredException":                  newErrorSourceFileOrContentRequiredException,
	"TagKeysListRequiredException":                          newErrorTagKeysListRequiredException,
	"TagPolicyException":                                    newErrorTagPolicyException,
	"TagsMapRequiredException":                              newErrorTagsMapRequiredException,
	"TargetRequiredException":                               newErrorTargetRequiredException,
	"TargetsRequiredException":                              newErrorTargetsRequiredException,
	"TipOfSourceReferenceIsDifferentException":              newErrorTipOfSourceReferenceIsDifferentException,
	"TipsDivergenceExceededException":                       newErrorTipsDivergenceExceededException,
	"TitleRequiredException":                                newErrorTitleRequiredException,
	"TooManyTagsException":                                  newErrorTooManyTagsException,
}
