// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package machinelearning provides the client and types for making API
// requests to Amazon Machine Learning.
//
// Definition of the public APIs exposed by Amazon Machine Learning
//
// See machinelearning package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/machinelearning/
//
// Using the Client
//
// To contact Amazon Machine Learning with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Machine Learning client MachineLearning for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/machinelearning/#New
package machinelearning
