// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package sagemakeredgemanager

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeInternalServiceException for service response error code
	// "InternalServiceException".
	//
	// An internal failure occurred. Try your request again. If the problem persists,
	// contact AWS customer support.
	ErrCodeInternalServiceException = "InternalServiceException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"InternalServiceException": newErrorInternalServiceException,
}
