// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package sagemakeredgemanager provides the client and types for making API
// requests to Amazon Sagemaker Edge Manager.
//
// SageMaker Edge Manager dataplane service for communicating with active agents.
//
// See https://docs.aws.amazon.com/goto/WebAPI/sagemaker-edge-2020-09-23 for more information on this service.
//
// See sagemakeredgemanager package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemakeredgemanager/
//
// Using the Client
//
// To contact Amazon Sagemaker Edge Manager with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Sagemaker Edge Manager client SagemakerEdgeManager for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemakeredgemanager/#New
package sagemakeredgemanager
