// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package mediaconnect

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAddFlowOutputs420Exception for service response error code
	// "AddFlowOutputs420Exception".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeAddFlowOutputs420Exception = "AddFlowOutputs420Exception"

	// ErrCodeBadRequestException for service response error code
	// "BadRequestException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeBadRequestException = "BadRequestException"

	// ErrCodeCreateFlow420Exception for service response error code
	// "CreateFlow420Exception".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeCreateFlow420Exception = "CreateFlow420Exception"

	// ErrCodeForbiddenException for service response error code
	// "ForbiddenException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeForbiddenException = "ForbiddenException"

	// ErrCodeGrantFlowEntitlements420Exception for service response error code
	// "GrantFlowEntitlements420Exception".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeGrantFlowEntitlements420Exception = "GrantFlowEntitlements420Exception"

	// ErrCodeInternalServerErrorException for service response error code
	// "InternalServerErrorException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeInternalServerErrorException = "InternalServerErrorException"

	// ErrCodeNotFoundException for service response error code
	// "NotFoundException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeNotFoundException = "NotFoundException"

	// ErrCodeServiceUnavailableException for service response error code
	// "ServiceUnavailableException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeServiceUnavailableException = "ServiceUnavailableException"

	// ErrCodeTooManyRequestsException for service response error code
	// "TooManyRequestsException".
	//
	// Exception raised by AWS Elemental MediaConnect. See the error message and
	// documentation for the operation for more information on the cause of this
	// exception.
	ErrCodeTooManyRequestsException = "TooManyRequestsException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AddFlowOutputs420Exception":        newErrorAddFlowOutputs420Exception,
	"BadRequestException":               newErrorBadRequestException,
	"CreateFlow420Exception":            newErrorCreateFlow420Exception,
	"ForbiddenException":                newErrorForbiddenException,
	"GrantFlowEntitlements420Exception": newErrorGrantFlowEntitlements420Exception,
	"InternalServerErrorException":      newErrorInternalServerErrorException,
	"NotFoundException":                 newErrorNotFoundException,
	"ServiceUnavailableException":       newErrorServiceUnavailableException,
	"TooManyRequestsException":          newErrorTooManyRequestsException,
}
