// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package imagebuilder provides the client and types for making API
// requests to EC2 Image Builder.
//
// EC2 Image Builder is a fully managed AWS service that makes it easier to
// automate the creation, management, and deployment of customized, secure,
// and up-to-date "golden" server images that are pre-installed and pre-configured
// with software and settings to meet specific IT standards.
//
// See https://docs.aws.amazon.com/goto/WebAPI/imagebuilder-2019-12-02 for more information on this service.
//
// See imagebuilder package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/imagebuilder/
//
// Using the Client
//
// To contact EC2 Image Builder with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the EC2 Image Builder client Imagebuilder for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/imagebuilder/#New
package imagebuilder
