// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package appintegrationsservice provides the client and types for making API
// requests to Amazon AppIntegrations Service.
//
// The Amazon AppIntegrations APIs are in preview release and are subject to
// change.
//
// The Amazon AppIntegrations service enables you to configure and reuse connections
// to external applications.
//
// For information about how you can use external applications with Amazon Connect,
// see Set up pre-built integrations (https://docs.aws.amazon.com/connect/latest/adminguide/crm.html)
// in the Amazon Connect Administrator Guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/appintegrations-2020-07-29 for more information on this service.
//
// See appintegrationsservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appintegrationsservice/
//
// Using the Client
//
// To contact Amazon AppIntegrations Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon AppIntegrations Service client AppIntegrationsService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appintegrationsservice/#New
package appintegrationsservice
