// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package sagemaker provides the client and types for making API
// requests to Amazon SageMaker Service.
//
// Provides APIs for creating and managing Amazon SageMaker resources.
//
// Other Resources:
//
//    * Amazon SageMaker Developer Guide (https://docs.aws.amazon.com/sagemaker/latest/dg/whatis.html#first-time-user)
//
//    * Amazon Augmented AI Runtime API Reference (https://docs.aws.amazon.com/augmented-ai/2019-11-07/APIReference/Welcome.html)
//
// See https://docs.aws.amazon.com/goto/WebAPI/sagemaker-2017-07-24 for more information on this service.
//
// See sagemaker package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemaker/
//
// Using the Client
//
// To contact Amazon SageMaker Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon SageMaker Service client SageMaker for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/sagemaker/#New
package sagemaker
