// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package workmailmessageflow provides the client and types for making API
// requests to Amazon WorkMail Message Flow.
//
// The WorkMail Message Flow API provides access to email messages as they are
// being sent and received by a WorkMail organization.
//
// See https://docs.aws.amazon.com/goto/WebAPI/workmailmessageflow-2019-05-01 for more information on this service.
//
// See workmailmessageflow package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/workmailmessageflow/
//
// Using the Client
//
// To contact Amazon WorkMail Message Flow with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon WorkMail Message Flow client WorkMailMessageFlow for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/workmailmessageflow/#New
package workmailmessageflow
