// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package emr provides the client and types for making API
// requests to Amazon Elastic MapReduce.
//
// Amazon EMR is a web service that makes it easier to process large amounts
// of data efficiently. Amazon EMR uses Hadoop processing combined with several
// AWS services to do tasks such as web indexing, data mining, log file analysis,
// machine learning, scientific simulation, and data warehouse management.
//
// See https://docs.aws.amazon.com/goto/WebAPI/elasticmapreduce-2009-03-31 for more information on this service.
//
// See emr package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/emr/
//
// Using the Client
//
// To contact Amazon Elastic MapReduce with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Elastic MapReduce client EMR for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/emr/#New
package emr
